import _extends from "@babel/runtime/helpers/extends";
// copy from https://github.com/KoryNunn/scroll-into-view/blob/05d319fe685411c60bd3f3d78d8114d7aa2f0037/scrollIntoView.js
var COMPLETE = 'complete';
var CANCELED = 'canceled';

function raf(task) {
  if ('requestAnimationFrame' in window) {
    return window.requestAnimationFrame(task);
  }

  setTimeout(task, 16);
}

function defaultIsWindow(target) {
  return target.self === target;
}

function setElementScroll(element, x, y) {
  if (defaultIsWindow(element)) {
    element.scrollTo(x, y);
  } else {
    element.scrollLeft = x;
    element.scrollTop = y;
  }
}

function getTargetScrollLocation(scrollSettings, parent) {
  var align = scrollSettings.align;
  var target = scrollSettings.target;
  var targetPosition = target.getBoundingClientRect();
  var parentPosition;
  var x;
  var y;
  var differenceX;
  var differenceY;
  var targetWidth;
  var targetHeight;
  var leftAlign = align && align.left != null ? align.left : 0.5;
  var topAlign = align && align.top != null ? align.top : 0.5;
  var leftOffset = align && align.leftOffset != null ? align.leftOffset : 0;
  var topOffset = align && align.topOffset != null ? align.topOffset : 0;
  var leftScalar = leftAlign;
  var topScalar = topAlign;

  if (defaultIsWindow(parent)) {
    targetWidth = Math.min(targetPosition.width, parent.innerWidth);
    targetHeight = Math.min(targetPosition.height, parent.innerHeight);
    x = targetPosition.left + parent.pageXOffset - parent.innerWidth * leftScalar + targetWidth * leftScalar;
    y = targetPosition.top + parent.pageYOffset - parent.innerHeight * topScalar + targetHeight * topScalar;
    x -= leftOffset;
    y -= topOffset;
    differenceX = x - parent.pageXOffset;
    differenceY = y - parent.pageYOffset;
  } else {
    targetWidth = targetPosition.width;
    targetHeight = targetPosition.height;
    parentPosition = parent.getBoundingClientRect();
    var offsetLeft = targetPosition.left - (parentPosition.left - parent.scrollLeft);
    var offsetTop = targetPosition.top - (parentPosition.top - parent.scrollTop);
    x = offsetLeft + targetWidth * leftScalar - parent.clientWidth * leftScalar;
    y = offsetTop + targetHeight * topScalar - parent.clientHeight * topScalar;
    x -= leftOffset;
    y -= topOffset;
    x = Math.max(Math.min(x, parent.scrollWidth - parent.clientWidth), 0);
    y = Math.max(Math.min(y, parent.scrollHeight - parent.clientHeight), 0);
    differenceX = x - parent.scrollLeft;
    differenceY = y - parent.scrollTop;
  }

  return {
    x: x,
    y: y,
    differenceX: differenceX,
    differenceY: differenceY
  };
}

function animate(parent) {
  var scrollSettings = parent._scrollSettings;

  if (!scrollSettings) {
    return;
  }

  var maxSynchronousAlignments = scrollSettings.maxSynchronousAlignments;
  var location = getTargetScrollLocation(scrollSettings, parent);
  var time = Date.now() - scrollSettings.startTime;
  var timeValue = Math.min(1 / scrollSettings.time * time, 1);

  if (scrollSettings.endIterations >= maxSynchronousAlignments) {
    setElementScroll(parent, location.x, location.y);
    parent._scrollSettings = null;
    return scrollSettings.end(COMPLETE);
  }

  var easeValue = 1 - scrollSettings.ease(timeValue);
  setElementScroll(parent, location.x - location.differenceX * easeValue, location.y - location.differenceY * easeValue);

  if (time >= scrollSettings.time) {
    scrollSettings.endIterations++;
    return animate(parent);
  }

  raf(animate.bind(null, parent));
}

function transitionScrollTo(target, parent, settings, callback) {
  var idle = !parent._scrollSettings;
  var lastSettings = parent._scrollSettings;
  var now = Date.now();
  var cancelHandler;
  var passiveOptions = {
    passive: true
  };

  if (lastSettings) {
    lastSettings.end(CANCELED);
  }

  function end(endType) {
    parent._scrollSettings = null;

    if (parent.parentElement && parent.parentElement._scrollSettings) {
      parent.parentElement._scrollSettings.end(endType);
    }

    callback(endType);

    if (cancelHandler) {
      parent.removeEventListener('touchstart', cancelHandler, passiveOptions);
      parent.removeEventListener('wheel', cancelHandler, passiveOptions);
    }
  }

  var maxSynchronousAlignments = settings.maxSynchronousAlignments;

  if (maxSynchronousAlignments == null) {
    maxSynchronousAlignments = 3;
  }

  parent._scrollSettings = {
    startTime: now,
    endIterations: 0,
    target: target,
    time: settings.time,
    ease: settings.ease,
    align: settings.align,
    maxSynchronousAlignments: maxSynchronousAlignments,
    end: end
  };

  if (!('cancellable' in settings) || settings.cancellable) {
    cancelHandler = end.bind(null, CANCELED);
    parent.addEventListener('touchstart', cancelHandler, passiveOptions);
    parent.addEventListener('wheel', cancelHandler, passiveOptions);
  }

  if (idle) {
    animate(parent);
  }
}

function directScrollTo(target, parent, settings, callback) {
  var scrollSettings = {
    target: target,
    ease: settings.ease,
    align: settings.align
  };
  var location = getTargetScrollLocation(scrollSettings, parent);
  setElementScroll(parent, location.x, location.y);
  callback && callback(COMPLETE);
}

function innerScrollTo(target, parent, settings, callback) {
  if (settings.behavior === 'auto') {
    directScrollTo(target, parent, settings, callback);
  } else {
    transitionScrollTo(target, parent, settings, callback);
  }
}

function findParentElement(el) {
  if (el.assignedSlot) {
    return findParentElement(el.assignedSlot);
  }

  if (el.parentElement) {
    if (el.parentElement.tagName === 'BODY') {
      return el.parentElement.ownerDocument.defaultView || el.parentElement.ownerDocument.ownerWindow;
    }

    return el.parentElement;
  }

  if (el.getRootNode) {
    var parent = el.getRootNode();

    if (parent.nodeType === 11) {
      return parent.host;
    }
  }
}

export var isScrollable = function isScrollable(element) {
  return 'pageXOffset' in element || (element.scrollHeight !== element.clientHeight || element.scrollWidth !== element.clientWidth) && getComputedStyle(element).overflow !== 'hidden';
};
export var findFirstScrollableParent = function findFirstScrollableParent(targetNode) {
  var scrollable = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : isScrollable;
  var innerParent = findParentElement(targetNode);

  if (!innerParent) {
    return;
  }

  if (scrollable(innerParent)) {
    return innerParent;
  }

  return findFirstScrollableParent(innerParent, scrollable);
};
var defaultSettings = {
  time: 500,
  ease: function ease(v) {
    return 1 - Math.pow(1 - v, v / 2);
  },
  validTarget: function validTarget() {
    return true;
  },
  behavior: 'smooth',
  isScrollable: isScrollable
};
export default function scrollIntoView(target, settings, cb) {
  var innerSettings = _extends({}, defaultSettings, settings);

  var parents = 0;

  var done = function done(endType) {
    parents--;

    if (!parents) {
      cb && cb(endType);
    }
  };

  var validTarget = innerSettings.validTarget,
      isScrollable = innerSettings.isScrollable,
      _innerSettings$onlyFi = innerSettings.onlyFirstScrollableParent,
      onlyFirstScrollableParent = _innerSettings$onlyFi === void 0 ? false : _innerSettings$onlyFi,
      parentNode = innerSettings.parentNode;

  if (parentNode) {
    parents++;
    innerScrollTo(target, parentNode, innerSettings, done);
    return;
  }

  var parent = findFirstScrollableParent(target, isScrollable);

  if (onlyFirstScrollableParent && parent && validTarget(parent, parents)) {
    parents++;
    innerScrollTo(target, parent, innerSettings, done);
    return;
  }

  while (parent) {
    if (validTarget(parent, parents)) {
      parents++;
      innerScrollTo(target, parent, innerSettings, done);
    }

    parent = findFirstScrollableParent(parent);

    if (!parent) {
      break;
    }
  }
}