import { ITheme } from '@muya-ui/theme-light';
import { Property } from 'csstype';
import React from 'react';
import { IMuyaComponent, IMuyaPureComponent, IReactElementWithRef, Omit } from '../types';
declare type EndHandler = (node: HTMLElement, done: () => void) => void;
declare type EnterHandler = (node: HTMLElement, isAppearing: boolean) => void;
declare type ExitHandler = (node: HTMLElement) => void;
declare const UNMOUNTED = "unmounted";
declare const EXITED = "exited";
declare const ENTERING = "entering";
declare const ENTERED = "entered";
declare const EXITING = "exiting";
interface TransitionActions {
    /**
     * 第一次挂载时不进行过渡动画，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    appear?: boolean;
    /**
     * 是否开启进入转换(关闭后不进入entering状态，直接进入entered状态)
     * * 注意当 appear 为 true 时此设置不会生效
     *
     * 详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    enter?: boolean;
    /**
     * 是否开启退出转换，与enter相反，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    exit?: boolean;
}
declare type TransitionStatus = typeof ENTERING | typeof ENTERED | typeof EXITING | typeof EXITED | typeof UNMOUNTED;
declare type TransitionChildren = React.ReactNode | ((status: TransitionStatus) => React.ReactNode);
interface PureTransitionProps extends TransitionActions {
    /**
     * 触发进入或退出状态，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    in?: boolean;
    /**
     * 默认情况子组件与transtion组件一起加载(也就是说即使in属性为false，组件也会先以隐藏状态(exited)正常加载)，当mountOnEnter 为true时，会在第一次in属性为true时加载子组件，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    mountOnEnter?: boolean;
    /**
     * 在过渡结束后卸载组件, 测试发现这里确实卸载了子组件生成的dom节点，但是并不会触发 componentWillUnmount 钩子，在子组件重新进入entered状态时也不会重新触发componentDidMount等创建阶段钩子，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    unmountOnExit?: boolean;
    /**
     * 转换的持续时间，可以传入对象以更细粒度的控制动画持续时间, 如果未传入 addEndListener 属性，此项为必传字段，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    timeout: number | {
        appear?: number;
        enter?: number;
        exit?: number;
    };
    /**
     * 用于手动触发动画结束状态的事件以允许你更细粒度的控制动画状态，传入改属性时，timeout属性扔作为后备属性生效，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    addEndListener?: EndHandler;
    /**
     * 进入 entering 状态之前触发的回调, 在第一次 mount 时会传入 isAppearing 判断是否开启 appear 选项，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onEnter?: EnterHandler;
    /**
     * 进入entering状态后触发的回调（也就是开始调用entering后触发），详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onEntering?: EnterHandler;
    /**
     * 进入entered状态后触发的回调，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onEntered?: EnterHandler;
    /**
     * 在exit状态前触发的回调，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onExit?: ExitHandler;
    /**
     * 在进入exiting状态后触发的回调，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onExiting?: ExitHandler;
    /**
     * 在进入exited状态后触发的回调，详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    onExited?: ExitHandler;
    /**
     * 详见：[Transition 文档](https://reactcommunity.org/react-transition-group/transition)
     */
    children?: TransitionChildren;
}
export interface TransitionProps extends PureTransitionProps {
    [prop: string]: any;
}
export interface IAnimationBaseParams {
    /** 动画时间 */
    timeout: number;
    /** 动画过渡曲线 */
    easing?: Property.TransitionTimingFunction;
    /** 动画样式 */
    style?: React.CSSProperties;
    /** 主题 */
    theme: ITheme;
}
export interface IAnimationBaseHooks {
    /** 在 exit 前的钩子 */
    beforeExit?(node: HTMLElement, props: IAnimationBaseParams): void;
    /** 在 enter 前的钩子 */
    beforeEnter?(node: HTMLElement, props: IAnimationBaseParams): void;
}
/**
 * 动画组件的通用 Props
 * @include
 */
export interface IAnimationBaseProps extends Omit<PureTransitionProps, 'timeout'>, IAnimationBaseHooks {
    /** 包裹的节点 */
    children: IReactElementWithRef;
    /**
     * 动画时间
     * @default 'theme.transiton.spec.duration.normal'
     **/
    timeout?: number;
    /**
     * 动画过渡曲线
     * @default 'theme.transiton.pattern.easing.status'
     */
    easing?: Property.TransitionTimingFunction;
    /** 样式 */
    style?: React.CSSProperties;
    /** 创建样式的函数 */
    makeStyles?(state: TransitionStatus, props: IAnimationBaseParams): React.CSSProperties;
}
export declare type ISlideAnimationDirection = 'up' | 'down' | 'left' | 'right';
export interface ICollapseAnimationProps extends IAnimationBaseProps {
    /**
     * 设置收起动画可以达到的最小高度，默认为0，即完全折叠
     *
     * @default 0
     * @type {number}
     * @memberof ICollapseAnimationProps
     */
    minHeight?: number;
}
export interface ISlideAnimationProps extends IAnimationBaseProps {
    /**
     * slide 进入的方向
     * @default 'up'
     **/
    direction?: ISlideAnimationDirection;
    /**
     * 最小的缩放比例
     * @default 0.8
     * @type {number}
     * @memberof ISlideAnimationProps
     */
    minScale?: number;
}
/**
 * @dts[only]
 */
export declare const Animation: {
    Fade: IMuyaPureComponent<IAnimationBaseProps, unknown>;
    Grow: IMuyaPureComponent<IAnimationBaseProps, unknown>;
    Collapse: IMuyaPureComponent<ICollapseAnimationProps, HTMLDivElement>;
    Slide: IMuyaComponent<ISlideAnimationProps, unknown>;
};
export declare const withAnimation: (makeStyles: IAnimationBaseProps['makeStyles'], hooksProps?: IAnimationBaseHooks) => IMuyaPureComponent<IAnimationBaseProps, unknown>;
export {};
