import React from 'react';
import { IInputTagValue, ITagInputRemoveEvent, ITagInputRenderTagProps } from '../Input';
import { ITriggerContainerFunc } from '../Trigger';
import { ICommonTriggerProps, ICustomStyleMap, ICustomStyleBaseProps, IFormBaseProps, IMuyaComponent, IPrefixSuffixNode, ISizeSpecBaseProps, Omit } from '../types';
export declare type ICascaderExpandTrigger = 'click' | 'hover';
export declare type ICascaderPlacement = 'top-start' | 'top-end' | 'bottom-start' | 'bottom-end';
/**
 * Cascader style keys
 * @styles inputWrapper 输入框容器
 * @styles panel 菜单面板
 * @styles menuBox 菜单滚动容器
 * @styles menu 菜单
 * @styles menuItem 菜单项
 * @styles resultMenu 搜索结果菜单
 * @styles resultMenuItem 搜索结果菜单项
 */
export declare type ICascaderStyleKeys = 'inputWrapper' | 'panel' | 'menuBox' | 'menu' | 'menuItem' | 'resultMenu' | 'resultMenuItem';
export declare type ICascaderValueType = string | number;
export interface ICascaderLoadKeysObject {
    loaded: ICascaderValueType[];
    loading: ICascaderValueType[];
}
export declare type ICascaderDisplayRender = (label: ICascaderValueType[], selectedOptions?: ICascaderOptionType[]) => string;
export interface ICascaderDataEntity {
    index: number;
    key: ICascaderValueType;
    pos: string;
    node: ICascaderOptionType;
    keyPath: ICascaderValueType[];
    parent?: ICascaderDataEntity;
    children?: ICascaderDataEntity[];
    level: number;
}
export interface IFieldNamesType {
    label?: string;
    value?: string;
    children?: string;
    isLeaf?: string;
}
export interface IFilledFieldNamesType {
    value: string;
    label: string;
    children: string;
    isLeaf: string;
}
export interface ICascaderOptionType {
    /**
     * 选项值
     */
    value?: ICascaderValueType;
    /**
     * 选项 label，不传则取 value
     */
    label?: string;
    /**
     * 选项禁用
     */
    disabled?: boolean;
    /**
     * 是否叶子，配合 loadData 使用
     */
    isLeaf?: boolean;
    /**
     * 是否加载中（下个版本将移除）
     * @deprecated
     */
    loading?: boolean;
    /**
     * 子节点
     */
    children?: Array<ICascaderOptionType>;
    /**
     * 自定义参数
     **/
    [customProp: string]: any;
}
export interface IFieldNamesType {
    label?: string;
    value?: string;
    children?: string;
}
export interface IFilledFieldNamesType {
    value: string;
    label: string;
    children: string;
}
export interface ICascaderSearchOptions {
    /**
     * 接收 `inputValue` `path` 两个参数，当 `path` 符合筛选条件时，应返回 `true`，反之则返回 `false`
     */
    filter?: (inputValue: string, path: ICascaderOptionType[], names: IFilledFieldNamesType) => boolean;
    /**
     * 搜索结果展示数量
     * @default 50
     */
    limit?: number | false;
    /**
     * 用于渲染 filter 后的选项
     */
    render?: (inputValue: string, path: ICascaderOptionType[], names: IFilledFieldNamesType) => React.ReactNode;
    /**
     * 用于排序 filter 后的选项
     */
    sort?: (a: ICascaderOptionType, b: ICascaderOptionType, inputValue: string, names: IFilledFieldNamesType) => number;
    /**
     * 搜索结果列表是否与输入框同宽
     * @default true
     */
    matchInputWidth?: boolean;
}
export declare type ICascaderInputValueInfo = {
    inputValue: string;
} | {
    inputValue: string;
    value: string[];
    disabledValue: string[];
};
export interface ICascaderBaseProps extends IFormBaseProps<ICascaderValueType[] | ICascaderValueType[][]>, ICommonTriggerProps, ISizeSpecBaseProps, ICustomStyleBaseProps<ICascaderStyleKeys> {
    /**
     * 允许清除，下个大版本改为默认 false
     * @default true
     */
    allowClear?: boolean;
    /**
     * 在 children 前增加节点
     */
    prefixNode?: React.ReactNode;
    /**
     * 开启多选
     * @default false
     */
    multiple?: boolean;
    /**
     * 多选模式下，节点选择完全受控（父子节点选中状态不再关联）
     * @default false
     */
    checkStrictly?: boolean;
    /**
     * 选项
     */
    options: Array<ICascaderOptionType>;
    /**
     * 外部控制是否弹出
     */
    popupVisible?: boolean;
    /**
     * 自定义 options 中 label name children 的字段
     * @default { label: 'label', value: 'value', children: 'children' }
     **/
    fieldNames?: IFieldNamesType;
    /**
     * 变更的回调
     */
    onChange?: (value: ICascaderValueType[] | ICascaderValueType[][], selectedOptions: ICascaderOptionType[] | ICascaderOptionType[][]) => void;
    /**
     * 默认已经加载的 Keys 非受控
     */
    defaultLoadedKeys?: ICascaderValueType[];
    /**
     * 已经加载的 Keys
     **/
    loadedKeys?: ICascaderValueType[];
    /**
     * 异步加载数据
     */
    loadData?: (activeOptions: ICascaderOptionType[]) => Promise<void> | void;
    /**
     * 节点加载完毕时触发
     **/
    onLoad?: (loadedKeys: ICascaderValueType[]) => void;
    /**
     * input 宽度
     */
    inputWidth?: number | string;
    /**
     * input 展开的 icon
     */
    inputExpandIcon?: React.ReactNode;
    /**
     * 只显示一个 tag，其余的合并
     * @default false
     **/
    collapseTags?: boolean;
    /**
     * tag 最大数量
     **/
    maxTagCount?: number;
    /**
     * tag 文案最大长度
     **/
    maxTagTextLength?: number;
    /**
     * 垂直方向最多几行 tag
     **/
    maxVerticalTagCount?: number;
    /**
     * tag 最大宽度
     **/
    maxTagWidth?: number;
    /**
     * input 节点的 ref
     */
    inputRef?: React.RefObject<HTMLInputElement>;
    /**
     * 自定义展示
     * @default (labels: string[]) => labels.join('/')
     */
    displayRender?: ICascaderDisplayRender;
    /**
     * 自定义渲染选项
     */
    renderOption?: (label: ICascaderOptionType, level?: number) => React.ReactNode;
    /**
     * 键盘事件监听
     */
    onKeyDown?: (e: React.SyntheticEvent) => void;
    /**
     * 子节点
     */
    children?: React.ReactElement;
    /**
     * 每个级别的 menu 宽度
     */
    menusWidth?: number[] | number;
    /**
     * 点击即触发数据变更，默认需要选择叶子节点才触发
     * @default false
     */
    changeOnSelect?: boolean;
    /**
     * 菜单展开的 icon
     */
    expandIcon?: React.ReactNode;
    /**
     * 菜单加载的 icon
     */
    loadingIcon?: React.ReactNode;
    /**
     * 弹出位置
     * @default 'bottom-start'
     */
    placement?: ICascaderPlacement;
    /**
     * 触发展开的行为：hover 或 click
     * @default 'click'
     */
    expandTrigger?: ICascaderExpandTrigger;
    /**
     * 弹出变更的回调
     */
    onPopupVisibleChange?: (popupVisible: boolean) => void;
    /**
     * 下拉面板的绑定节点
     * @default () => document.body
     */
    getPopupContainer?: ITriggerContainerFunc;
    /**
     * 默认受控时需要传入完整的节点路径上的 value，如果只想要传入叶子节点的 value 来做受控，可以开启此选项
     * @default false
     */
    controlLeaf?: boolean;
    /**
     * 启用搜索
     */
    showSearch?: boolean | ICascaderSearchOptions;
    /**
     * 每页展示的结果数量
     * @default 6.5
     */
    maxItemCountPerPage?: number;
    /**
     * 搜索无结果展示的内容
     **/
    notFoundContent?: React.ReactElement;
    /**
     * 多选，自定义 Tag 的渲染，建议基于 InputTag 进行自定义
     */
    renderTag?: (props: ITagInputRenderTagProps) => React.ReactNode;
    /**
     * 开启虚拟列表
     */
    virtual?: boolean;
    /**
     * 菜单滚动事件
     * @param e 滚动事件
     * @param menuLevel 当前滚动的菜单层级
     * @param activeOptions 当前激活的 options
     */
    onMenuScroll?: (e: React.UIEvent, menuLevel: number, activeOptions: ICascaderOptionType[]) => void;
}
export declare type ICascaderProps = ICascaderBaseProps & Omit<React.HTMLAttributes<HTMLInputElement>, 'value' | 'defaultValue' | 'onKeyDown' | 'onChange'>;
export interface ICascaderPanelBaseProps extends ISizeSpecBaseProps, ICustomStyleBaseProps<ICascaderStyleKeys> {
    /** 默认值 */
    defaultValue?: ICascaderValueType[] | ICascaderValueType[][];
    /** 当前值 */
    value?: ICascaderValueType[] | ICascaderValueType[][];
    /**
     * 开启多选
     * @default false
     */
    multiple?: boolean;
    /**
     * 多选模式下，节点选择完全受控（父子节点选中状态不再关联）
     * @default false
     */
    checkStrictly?: boolean;
    /**
     * 选项
     */
    options: Array<ICascaderOptionType>;
    /**
     * 自定义 options 中 label name children 的字段
     * @default { label: 'label', value: 'value', children: 'children' }
     **/
    fieldNames?: IFieldNamesType;
    /**
     * 变更的回调
     */
    onChange?: (value: ICascaderValueType[] | ICascaderValueType[][], selectedOptions: ICascaderOptionType[] | ICascaderOptionType[][]) => void;
    /**
     * 默认已经加载的 Keys 非受控
     */
    defaultLoadedKeys?: ICascaderValueType[];
    /**
     * 已经加载的 Keys
     **/
    loadedKeys?: ICascaderValueType[];
    /**
     * 异步加载数据
     */
    loadData?: (activeOptions: ICascaderOptionType[]) => Promise<void> | void;
    /**
     * 节点加载完毕时触发
     **/
    onLoad?: (loadedKeys: ICascaderValueType[]) => void;
    /**
     * 自定义渲染选项
     */
    renderOption?: (label: ICascaderOptionType, level?: number) => React.ReactNode;
    /**
     * 每个级别的 menu 宽度
     */
    menusWidth?: number[] | number;
    /**
     * 点击即触发数据变更，默认需要选择叶子节点才触发
     * @default false
     */
    changeOnSelect?: boolean;
    /**
     * 菜单展开的 icon
     */
    expandIcon?: React.ReactNode;
    /**
     * 菜单加载的 icon
     */
    loadingIcon?: React.ReactNode;
    /**
     * 触发展开的行为：hover 或 click
     * @default 'click'
     */
    expandTrigger?: ICascaderExpandTrigger;
    /**
     * 默认受控时需要传入完整的节点路径上的 value，如果只想要传入叶子节点的 value 来做受控，可以开启此选项
     * @default false
     */
    controlLeaf?: boolean;
    /**
     * 开启虚拟列表
     */
    virtual?: boolean;
    /**
     * 菜单滚动事件
     * @param e 滚动事件
     * @param menuLevel 当前滚动的菜单层级
     * @param activeOptions 当前激活的 options
     */
    onMenuScroll?: (e: React.UIEvent, menuLevel: number, activeOptions: ICascaderOptionType[]) => void;
}
export declare type ICascaderPanelProps = ICascaderPanelBaseProps & Omit<React.HTMLAttributes<HTMLInputElement>, 'value' | 'defaultValue' | 'onChange'>;
export interface ICascaderInputBaseProps extends IFormBaseProps<string[]>, IPrefixSuffixNode, ISizeSpecBaseProps {
    /**
     * tag 最大数量
     **/
    maxTagTextLength?: number;
    /**
     * 垂直方向最多几行 tag
     **/
    maxVerticalTagCount: number;
    /**
     * tag 最大宽度
     **/
    maxTagWidth?: number;
    /**
     * 展开 icon
     **/
    expandIcon?: React.ReactNode;
    /**
     * 输入框值
     **/
    inputValue: string;
    /**
     * 禁用的值
     */
    disabledValue?: string[];
    /**
     * 弹出状态
     **/
    popupVisible: boolean;
    /**
     * 是否多选
     **/
    multiple: boolean;
    /**
     * 自定义 options 中 label name children 的字段
     * @default { label: 'label', value: 'value', children: 'children' }
     */
    fieldNames: IFilledFieldNamesType;
    /**
     * 清除按钮点击回调
     **/
    onClear?: React.MouseEventHandler;
    /**
     * 输入事件
     */
    onInput?: React.ChangeEventHandler;
    /**
     * 输入框键盘事件
     **/
    onKeyDown?: React.KeyboardEventHandler<HTMLInputElement>;
    /**
     * 移除 tag 事件
     */
    onRemoveTag: (value: IInputTagValue, index: number, e: ITagInputRemoveEvent) => void;
    /**
     * 选择器宽度
     **/
    width?: number | string;
    /**
     * select 内部 input 的 ref
     */
    inputRef?: React.Ref<HTMLInputElement>;
    /**
     * 存在关联的值
     */
    hasRelatedValue?: boolean;
    /**
     * 启用搜索
     */
    showSearch?: boolean;
    /**
     * 多选，自定义 Tag 的渲染，建议基于 InputTag 进行自定义
     */
    renderTag?: (props: ITagInputRenderTagProps) => React.ReactNode;
}
export declare type ICascaderInputProps = ICascaderInputBaseProps & Omit<React.HTMLAttributes<HTMLInputElement>, 'onKeyDown' | 'onChange' | 'value' | 'defaultValue'>;
export interface IPureCascaderPanelProps extends ISizeSpecBaseProps, ICustomStyleBaseProps<ICascaderStyleKeys> {
    /**
     * 多选的选中状态
     */
    checkedKeys: {
        checked: ICascaderDataEntity[];
        halfChecked: ICascaderDataEntity[];
    };
    /**
     * 加载中的 keys
     */
    loadingKeys: ICascaderValueType[];
    /**
     * 加载完成的 keys
     */
    loadedKeys: ICascaderValueType[];
    /**
     * 加载函数
     */
    onLoad: (targetValue: ICascaderValueType, activeOptions?: ICascaderOptionType[]) => Promise<void>;
    /**
     * 是否多选
     */
    multiple: boolean;
    /**
     * 激活项
     */
    activeValue: ICascaderValueType[];
    /**
     * 选项
     */
    options: Array<ICascaderOptionType>;
    /**
     * 自定义 options 中 label name children 的字段
     * @default { label: 'label', value: 'value', children: 'children' }
     */
    fieldNames: IFilledFieldNamesType;
    /**
     * 触发展开的方式
     */
    expandTrigger: ICascaderExpandTrigger;
    /**
     * 菜单是否可见
     * @default false
     */
    visible: boolean;
    /**
     * 展开的 icon
     */
    expandIcon?: React.ReactNode;
    /**
     * 加载的 icon
     */
    loadingIcon?: React.ReactNode;
    /**
     * 可配置的菜单宽度
     */
    menusWidth?: number[] | number;
    /**
     * 弹出位置
     * @default 'bottom-start'
     */
    placement: ICascaderPlacement;
    /**
     * menu 是否反向
     */
    menuReverse: boolean;
    /**
     * 选择的回调
     */
    onSelect: (targetOption: ICascaderOptionType, menuIndex: number, e: React.MouseEvent | React.KeyboardEvent | React.ChangeEvent) => void;
    /** 取消选中的回调 */
    onDeselect: (targetOptions: ICascaderOptionType[], menuIndex: number, e: React.MouseEvent | React.ChangeEvent) => void;
    /**
     * 自定义渲染选项
     */
    renderOption?: (label: ICascaderOptionType, level?: number) => React.ReactNode;
    /**
     * 开启虚拟列表
     */
    virtual?: boolean;
    /**
     * 菜单滚动事件
     * @param e 滚动事件
     * @param menuLevel 当前滚动的菜单层级
     * @param activeOptions 当前激活的 options
     */
    onMenuScroll?: (e: React.UIEvent, menuLevel: number, activeOptions: ICascaderOptionType[]) => void;
    /**
     * 只渲染 panel
     */
    pure?: boolean;
}
export interface ICascaderMenuProps extends Pick<IPureCascaderPanelProps, 'size' | 'menuReverse' | 'expandTrigger' | 'checkedKeys' | 'fieldNames' | 'multiple' | 'placement' | 'expandIcon' | 'loadingIcon' | 'loadingKeys' | 'loadedKeys' | 'onLoad' | 'onSelect' | 'onDeselect' | 'renderOption' | 'virtual' | 'onMenuScroll'> {
    menuIndex: number;
    menuWidth: number;
    activeOptions: ICascaderOptionType[];
    activeOptionsRef: React.MutableRefObject<HTMLLIElement[]>;
    options: Array<ICascaderOptionType>;
    styles: ICustomStyleMap<'menuBox' | 'menu' | 'menuItem'>;
}
export interface ICascaderMenuItemProps extends Pick<IPureCascaderPanelProps, 'size' | 'expandTrigger' | 'checkedKeys' | 'fieldNames' | 'multiple' | 'expandIcon' | 'loadingIcon' | 'onSelect' | 'onDeselect' | 'placement' | 'renderOption'> {
    menuIndex: number;
    option: ICascaderOptionType;
    active: boolean;
    activeOptionsRef: React.MutableRefObject<HTMLLIElement[]>;
    loading: boolean;
    loaded: boolean;
    onLoad: (targetValue: ICascaderValueType, activeOptions?: ICascaderOptionType[]) => Promise<void>;
    className: string;
    style?: React.CSSProperties;
}
/**
 * dts[only]
 */
export declare const CascaderPanel: IMuyaComponent<ICascaderPanelProps, HTMLDivElement, {
    __MUYA_CASCADERPANEL: true;
}>;
export declare const Cascader: IMuyaComponent<ICascaderProps, HTMLDivElement, {
    __MUYA_CASCADER: true;
    Panel: typeof CascaderPanel;
}>;
