import { ConfigType, Dayjs } from 'dayjs';
import React from 'react';
import { ICalendarPureProps, ICalendarUIChangeEvent, IMultiSelectCalendarPureProps, IMultiSelectCalendarUIChangeEvent, IRangeCalendarChangeEvent, IRangeCalendarPureProps, IRangeCalendarUIChangeEvent } from '../Calendar';
import { IInputOnlyInputStyleKeys, IInputPureProps, IRangeInputPureProps, IRangeInputStyleKeys, ITagsInputProps } from '../Input';
import { ITriggerContainerFunc, ITriggerProps } from '../Trigger';
import { ICommonTriggerProps, ICustomStyleBaseProps, IMuyaPureComponent, Omit } from '../types';
declare type IPropsFromCalendar = Omit<ICalendarPureProps, 'defaultDate' | 'styles' | 'onChange' | 'onUIChange' | 'allowClear'>;
/**
 * DatePicker style keys
 *
 * @styles popPanel 弹出的面板容器
 */
export declare type IDatePickerStyleKeys = 'popPanel' | IInputOnlyInputStyleKeys;
/**
 * 日期选择器格式化类型
 */
export declare type IDatePickerFormat = string | ((date: Dayjs) => string);
/**
 * RangeDatePicker style keys
 *
 * @styles popPanel 弹出的面板容器
 */
export declare type IRangeDatePickerStyleKeys = 'popPanel' | IRangeInputStyleKeys;
export interface IDatePickerBaseProps extends ICommonTriggerProps {
    /**
     * 日期格式化的字符串，参考 https://github.com/iamkun/dayjs
     * 默认值随 `selectType` 变化
     *  * `selectType === 'date'` format 为 `YYYY-MM-DD`
     *  * `selectType === 'month'` format 为 `YYYY-MM`
     *  * `selectType === 'year'` format 为 `YYYY`
     */
    format?: IDatePickerFormat;
    /**
     * 日期的位置
     * @default 'bottom-start'
     */
    placement?: ITriggerProps['placement'];
    /** 日期面板的显示/隐藏 */
    popupOpen?: boolean;
    /**
     * 设置输入框为只读
     */
    inputReadOnly?: boolean;
    /** 日期面板绑定的容器 */
    getPopupContainer?: ITriggerContainerFunc;
    /** 菜单打开关闭的回调 */
    onPopupVisibleChange?: (open: boolean) => void;
    /**
     * 日历组件的样式重置，详见 [日历样式重置](../components/calendar#styles)
     */
    calendarStyles?: ICalendarPureProps['styles'];
    /**
     * input 输入框 debounce 延时触发日历面板的UI同步
     * @default 200
     */
    inputDelay?: number;
    /**
     * 是否允许清空选择的日期
     * @default true
     */
    allowClear?: boolean;
}
export interface IDatePickerUIChangeEvent extends ICalendarUIChangeEvent {
    /** 面板是否显示 */
    popupOpen: boolean;
}
declare type IPropsFromInput = Omit<IInputPureProps, 'defaultValue' | 'value' | 'limit' | 'multiline' | 'autosize' | 'allowClear' | 'maxRows' | 'minRows' | 'focusWhenClear' | 'styles'>;
declare type onSingleUIChangeEvent = (event: IDatePickerUIChangeEvent) => void;
declare type onMultipleUIChangeEvent = (event: IMultiSelectDatePickerUIChangeEvent) => void;
declare type onSingleChangeEvent = (date: Dayjs) => void;
declare type onMultipleChangeEvent = (date: Dayjs[]) => void;
declare type onSingleDateChangeEvent = (value: string, date: Dayjs) => void;
declare type onMultipleDateChangeEvent = (value: string[], date: Dayjs[]) => void;
declare type onSingleCalendarChangeEvent = (date?: Dayjs) => void;
declare type onMultipleCalendarChangeEvent = (date?: Dayjs[]) => void;
export interface ISingleDatePickerPureProps extends IDatePickerBaseProps, ICustomStyleBaseProps<IDatePickerStyleKeys>, IPropsFromInput, IPropsFromCalendar {
    /** DatePicker 的值 */
    value?: ConfigType;
    /** DatePicker 的默认值 */
    defaultValue?: ConfigType;
    /**
     * 已废弃，请使用 `defaultViewDate`
     * @deprecated
     */
    defaultDate?: ConfigType;
    /** UI的状态变化，包括面板的翻页、切换、展开收起 */
    onUIChange?: onSingleUIChangeEvent;
    /** DatePicker 变化的值，注意 value === '' 时，date.isValid() === false */
    onChange?: onSingleChangeEvent;
    /** 同 onChange 一样，多传了一个 string */
    onDateChange?: onSingleDateChangeEvent;
    /**
     * Calender的 onChange 透传
     */
    onCalendarChange?: onSingleCalendarChangeEvent;
}
export interface IDatePickerPureProps extends IDatePickerBaseProps, ICustomStyleBaseProps<IDatePickerStyleKeys>, IPropsFromInput, IPropsFromCalendar {
    /** DatePicker 的值 */
    value?: ConfigType | ConfigType[];
    /** DatePicker 的默认值 */
    defaultValue?: ConfigType | ConfigType[];
    /** 是否开启多选模式 */
    multiple?: boolean;
    /**
     * 已废弃，请使用 `defaultViewDate`
     * @deprecated
     */
    defaultDate?: ConfigType;
    /** UI的状态变化，包括面板的翻页、切换、展开收起 */
    onUIChange?: onSingleUIChangeEvent | onMultipleUIChangeEvent;
    /** DatePicker 变化的值，注意 value === '' 时，date.isValid() === false */
    onChange?: onSingleChangeEvent | onMultipleChangeEvent;
    /** 同 onChange 一样，多传了一个 string */
    onDateChange?: onSingleDateChangeEvent | onMultipleDateChangeEvent;
    /**
     * Calender的 onChange 透传
     */
    onCalendarChange?: onSingleCalendarChangeEvent | onMultipleCalendarChangeEvent;
}
export declare type IDatePickerProps = IDatePickerPureProps & Omit<React.InputHTMLAttributes<HTMLInputElement>, 'size' | 'onClick' | 'onMouseLeave' | 'onMouseEnter' | 'value' | 'defaultValue' | 'onChange' | 'onSelect'>;
export declare type ISingleDatePickerProps = ISingleDatePickerPureProps & Omit<React.InputHTMLAttributes<HTMLInputElement>, 'size' | 'onClick' | 'onMouseLeave' | 'onMouseEnter' | 'value' | 'defaultValue' | 'onChange' | 'onSelect'>;
export interface IMultiSelectDatePickerBaseProps extends ICommonTriggerProps {
    /**
     * 日期格式化的字符串，参考 https://github.com/iamkun/dayjs
     * 默认值随 `selectType` 变化
     *  * `selectType === 'date'` format 为 `YYYY-MM-DD`
     *  * `selectType === 'month'` format 为 `YYYY-MM`
     *  * `selectType === 'year'` format 为 `YYYY`
     */
    format?: IDatePickerFormat;
    /**
     * 日期的位置
     * @default 'bottom-start'
     */
    placement?: ITriggerProps['placement'];
    /** 日期面板的显示/隐藏 */
    popupOpen?: boolean;
    /**
     * 设置输入框为只读
     */
    inputReadOnly?: boolean;
    /** 日期面板绑定的容器 */
    getPopupContainer?: ITriggerContainerFunc;
    /** 菜单打开关闭的回调 */
    onPopupVisibleChange?: (open: boolean) => void;
    /**
     * 日历组件的样式重置，详见 [日历样式重置](../components/calendar#styles)
     */
    calendarStyles?: IMultiSelectCalendarPureProps['styles'];
    /**
     * input 输入框 debounce 延时触发日历面板的UI同步
     * @default 200
     */
    inputDelay?: number;
    /**
     * 是否允许清空选择的日期
     * @default true
     */
    allowClear?: boolean;
}
export interface IMultiSelectDatePickerUIChangeEvent extends IMultiSelectCalendarUIChangeEvent {
    /** 面板是否显示 */
    popupOpen: boolean;
}
declare type IPropsFromTagInput = Omit<ITagsInputProps, 'defaultValue' | 'value' | 'limit' | 'multiline' | 'autosize' | 'allowClear' | 'maxRows' | 'minRows' | 'focusWhenClear' | 'styles' | 'allowAdd' | 'maxVerticalTagCount' | 'onAddTag' | 'onRemoveTag' | 'onSelect' | 'onChange'>;
declare type IPropsFromMultiSelectCalendar = Omit<IMultiSelectCalendarPureProps, 'defaultDate' | 'styles' | 'onChange' | 'onUIChange' | 'allowClear'>;
export interface IMultiSelectDatePickerPureProps extends IMultiSelectDatePickerBaseProps, ICustomStyleBaseProps<IDatePickerStyleKeys>, IPropsFromTagInput, IPropsFromMultiSelectCalendar {
    /** MultiSelectDatePicker 的值 */
    value?: ConfigType[];
    /** MultiSelectDatePicker 的默认值 */
    defaultValue?: ConfigType[];
    /** UI的状态变化，包括面板的翻页、切换、展开收起 */
    onUIChange?: onMultipleUIChangeEvent;
    /** MultiSelectDatePicker 变化的值，注意 value === '' 时，date.isValid() === false */
    onChange?: onMultipleChangeEvent;
    /** 同 onChange 一样，多传了一个 string */
    onDateChange?: onMultipleDateChangeEvent;
    /**
     * Calender的 onChange 透传
     */
    onCalendarChange?: onMultipleCalendarChangeEvent;
}
export declare type IMultiSelectDatePickerProps = IMultiSelectDatePickerPureProps & Omit<React.InputHTMLAttributes<HTMLInputElement>, 'size' | 'onClick' | 'onMouseLeave' | 'onMouseEnter' | 'value' | 'defaultValue' | 'onChange' | 'onSelect'>;
export interface IRangeDatePickerUIChangeEvent extends IRangeCalendarUIChangeEvent {
    /** 面板是否显示 */
    popupOpen: boolean;
}
declare type IPropsFromRangeCalendar = Omit<IRangeCalendarPureProps, 'defaultRange' | 'styles' | 'onChange' | 'onUIChange' | 'allowClear'>;
declare type IPropsFromRangeInput = Omit<IRangeInputPureProps, 'value' | 'suffixNode' | 'allowClear' | 'clearReplace' | 'onChange' | 'focusWhenClear' | 'defaultValue' | 'styles'>;
export interface IRangeDatePickerPureProps extends IDatePickerBaseProps, ICustomStyleBaseProps<IRangeDatePickerStyleKeys>, IPropsFromRangeCalendar, IPropsFromRangeInput {
    /**
     * 已废弃，请使用 `defaultViewDate`
     * @deprecated
     */
    defaultRange?: ConfigType[];
    /**
     * RangeDatePicker 的值
     */
    value?: ConfigType[];
    /**
     * RangeDatePicker 的默认值
     */
    defaultValue?: ConfigType[];
    /**
     * 只读属性
     */
    readOnly?: boolean;
    /** UI的状态变化，包括面板的翻页、切换、展开收起 */
    onUIChange?: (event: IRangeDatePickerUIChangeEvent) => void;
    /**
     * 注意当 value === ['', ''] 时，range[0 | 1].isValid() === false
     */
    onChange?: (range: [Dayjs, Dayjs]) => void;
    /** 同 onChange 一样，多传了一个 [string, string] */
    onDateChange?: (value: [string, string], range: [Dayjs, Dayjs]) => void;
    /** RangeCalendar 的 onChange 透传 */
    onCalendarChange?: (state: IRangeCalendarChangeEvent) => void;
}
export declare type IRangeDatePickerProps = IRangeDatePickerPureProps & Pick<React.InputHTMLAttributes<HTMLInputElement>, 'autoFocus' | 'width' | 'height'> & Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange' | 'onSelect' | 'defaultValue' | 'placeholder'>;
/**
 * @dts[only]
 */
export declare const DatePicker: IMuyaPureComponent<IDatePickerProps, HTMLDivElement, {
    __MUYA_DATEPICKER: true;
}>;
export declare const RangeDatePicker: IMuyaPureComponent<IRangeDatePickerProps, HTMLDivElement, {
    __MUYA_RANGEDATEPICKER: true;
}>;
export {};
