import { ConfigType, Dayjs } from 'dayjs';
import React from 'react';
import { ICalendarPureProps, ICalendarStyleKeys } from '../Calendar';
import { IDatePickerUIChangeEvent } from '../DatePicker';
import { IInputOnlyInputStyleKeys, IInputPureProps } from '../Input';
import { ITimePickerPanelPureProps } from '../TimePicker';
import { ITriggerContainerFunc, ITriggerProps } from '../Trigger';
import { ICommonTriggerProps, ICustomStyleBaseProps, IMuyaPureComponent, Omit } from '../types';
declare type IPropsFromCalendar = Omit<ICalendarPureProps, 'selectType' | 'styles' | 'onChange' | 'selectedDate' | 'defaultDate' | 'onSelect'>;
declare type IPropsFromTimePickerPanel = Omit<ITimePickerPanelPureProps, 'styles' | 'onChange' | 'value' | 'defaultValue' | 'rowNum' | 'format'>;
export interface IDateTimeCalendarPureProps extends IPropsFromCalendar, IPropsFromTimePickerPanel, ICustomStyleBaseProps<IDateTimeCalendarStyleKeys> {
    /** 日期的值，受控时使用，比如 '2020-07-06 22:00:09' */
    selectedDate?: ConfigType;
    /** 默认值，比如 '2020-07-06 22:00:09' */
    defaultDate?: ConfigType;
    /**
     * 选择日期后，默认的时间
     * > 注意： 默认是 `'now'` 表示现在的时间，如果是 `string` ，则必须是 `HH:mm:ss` 格式，比如 `'20:00:00'`
     */
    defaultTime?: 'now' | string;
    /**
     * 禁用什么时间之前的选项
     * > 注意：当 `disableTimeBefore === '2020-08-17 20:30:30'` 时，`'2020-08-17 20:30:30'` 是可选的
     */
    disableTimeBefore?: ConfigType;
    /**
     * 禁用什么时间之后的选项
     * > 注意：当 `disableTimeAfter === '2020-08-17 20:30:30'` 时，`'2020-08-17 20:30:30'` 是可选的
     */
    disableTimeAfter?: ConfigType;
    /** 受控使用 */
    onChange?: (date?: Dayjs) => void;
    /** 清空时触发 */
    onClear?: () => void;
    /** 选中时触发 */
    onSelect?: (date: Dayjs) => void;
    /** 确认按钮点击触发 */
    onConfirm?: (date: Dayjs) => void;
    /** 时间的格式 */
    timeFormat?: string;
    /** 时间选项的行数 */
    timeRowNum?: number;
}
export declare type IDateTimeCalendarProps = IDateTimeCalendarPureProps & Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange' | 'onSelect' | 'defaultValue'>;
declare type IPropsFromDateTimeCalendar = Omit<IDateTimeCalendarProps, 'styles' | 'onChange' | 'onUIChange' | 'allowClear' | 'defaultDate' | 'selectedDate' | 'onSelect'>;
declare type IPropsFromInput = Omit<IInputPureProps, 'defaultValue' | 'value' | 'limit' | 'multiline' | 'autosize' | 'allowClear' | 'maxRows' | 'minRows' | 'focusWhenClear' | 'styles' | 'readOnly' | 'onClear'>;
/**
 * DateTimeCalendar style keys
 *
 * @styles popPanel 弹出浮层
 * @styles dateTimePanel 日期和时间的容器
 * @styles dateCol 日期的列
 * @styles timeCol 时间的列
 * @styles timeHead 时间的头部容器
 * @styles timeHeadText 时间标题
 * @styles timePanel 时间面板
 * @styles footerContainer 面板底部容器
 * @styles buttonContainer 按钮容器
 * @styles clearButton 清空按钮
 * @styles confirmButton 确认按钮
 */
export declare type IDateTimeCalendarStyleKeys = ICalendarStyleKeys | 'dateTimePanel' | 'dateCol' | 'timeCol' | 'timeHead' | 'timeHeadText' | 'timePanel' | 'footerContainer' | 'buttonContainer' | 'clearButton' | 'confirmButton';
/**
 * ScrollView style keys
 *
 * @styles popPanel 弹出浮层
 */
export declare type IDateTimePickerStyleKeys = 'popPanel' | IInputOnlyInputStyleKeys;
export interface IDateTimePickerBaseProps extends ICustomStyleBaseProps<IDateTimePickerStyleKeys>, IPropsFromInput, ICommonTriggerProps, IPropsFromDateTimeCalendar {
    /** 日期的值，受控时使用，比如 '2020-07-06 22:00:09' */
    value?: ConfigType;
    /** 默认值，比如 '2020-07-06 22:00:09' */
    defaultValue?: ConfigType;
    /**
     * 日期格式化，参考 https://github.com/iamkun/dayjs
     * @default 'YYYY-MM-DD HH:mm:ss'
     */
    format?: string | ((date: Dayjs) => string);
    /**
     * 时间格式化，参考 https://github.com/iamkun/dayjs
     * 会自动从 format 获取，如果不设置的话
     * @default 'HH:mm:ss'
     */
    timeFormat?: string;
    /**
     * 日期的位置
     * @default 'bottom'
     */
    placement?: ITriggerProps['placement'];
    /** 日期面板的显示/隐藏 */
    popupOpen?: boolean;
    /** 日期面板绑定的容器 */
    getPopupContainer?: ITriggerContainerFunc;
    /**
     * 日历组件的样式重置，详见 [日历样式重置](../components/calendar#styles)
     */
    calendarStyles?: IDateTimeCalendarProps['styles'];
    /**
     * 是否允许清空选择的日期
     * @default true
     */
    allowClear?: boolean;
    /** UI的状态变化，包括面板的翻页、切换、展开收起 */
    onUIChange?: (event: IDatePickerUIChangeEvent) => void;
    /** DatePicker 变化的值，注意 value === '' 时，date.isValid() === false */
    onChange?: (date: Dayjs) => void;
    /**
     * Calender的 onChange 透传
     */
    onCalendarChange?: (week?: Dayjs) => void;
}
export declare type IDateTimePickerProps = IDateTimePickerBaseProps & Omit<React.InputHTMLAttributes<HTMLInputElement>, 'size' | 'onClick' | 'onMouseLeave' | 'onMouseEnter' | 'value' | 'defaultValue' | 'onChange' | 'onSelect'>;
/**
 * @dts[only]
 */
export declare const DateTimePicker: IMuyaPureComponent<IDateTimePickerProps, HTMLDivElement, {
    __MUYA_DATETIMEPICKER: true;
}>;
export {};
