import React from 'react';
import { IPopoverCardProps } from '../PopoverCard';
import { IPopperPlacement, IPopperProps } from '../Popper';
import { ITriggerArrowStyle } from '../Trigger';
import { ICustomStyleBaseProps, IMuyaPureComponent } from '../types';
/**
 * @styles content 内容
 * @styles skip 跳过
 * @styles next 下一项
 * @styles text 文本
 * @styles close 关闭
 * @styles inform inform 图标
 * @styles title 标题
 * @styles subTitle 子标题
 */
export declare type IGuideStyleKeys = 'content' | 'skip' | 'next' | 'text' | 'close' | 'inform' | 'title' | 'subTitle';
export declare type IGuideStepPosition = 'left' | 'right' | 'top' | 'bottom';
interface IStepContentArgs {
    close: () => void;
    goTo: (step: number) => void;
    step: number;
}
export declare type IGuideNode = string | Element;
export interface IGuideStep {
    /**
     * 引导文案或自定义引导框
     */
    content: React.ReactNode | ((args: IStepContentArgs) => React.ReactNode);
    /**
     * 副标题文案
     */
    subTitle?: React.ReactNode;
    /**
     * DOM 选择器或者 DOM 节点
     */
    selector: IGuideNode | IGuideNode[];
    /**
     * 引导弹出位置。如果选择的 DOM 靠近屏幕右侧边界且 position 为 right，引导框位置将会自适应改变为 left
     * @default bottom
     */
    position?: IPopperPlacement;
    /**
     * 箭头指示位置。特殊情况下需要自定义箭头位置，比如选择的 DOM 靠近屏幕右侧边界
     * @default `${position}-start`
     * @deprecated
     */
    arrowPosition?: IPopperPlacement;
    /**
     * 弹出框样式
     */
    style?: React.CSSProperties;
    /**
     * 定制主副标题及 Icon 样式
     */
    customTextWrapper?: React.ReactNode;
    /**
     * 保留 ToolTip 下一步按钮
     * @default true
     */
    showNextButton?: boolean;
    /**
     * 下一步按钮是否可点击
     */
    canNext?: () => boolean | Promise<unknown>;
    /**
     * 自定义 popper 参数
     */
    popperProps?: Partial<IPopperProps>;
    /**
     * 滚动容器，覆盖 IGuideProps 上的
     */
    scroller?: HTMLElement;
    /**
     * 高亮框边距
     */
    maskSpace?: number;
}
export interface IGuideProps extends ICustomStyleBaseProps<IGuideStyleKeys> {
    /**
     * 引导步骤配置
     */
    steps: Array<IGuideStep>;
    /**
     * 关闭事件
     */
    onRequestClose: () => void;
    /**
     * 自定义箭头大小、颜色
     */
    arrowStyle?: ITriggerArrowStyle;
    /**
     * 是否显示 Close Icon
     * @default true
     */
    showClose?: boolean;
    /**
     * 是否显示跳过文案
     * @default true
     */
    showSkip?: boolean;
    /**
     * 跳过文案
     * @default 跳过引导
     */
    skipText?: string;
    /**
     * 下一步文案
     * @default 下一步(index/total)
     */
    nextText?: string;
    /**
     * 确认完成引导文案
     * @default 完成
     */
    confirmText?: string;
    /**
     * 高亮框边距
     * @default 0
     */
    maskSpace?: number;
    /**
     * 高亮框圆角
     * @default 0
     */
    rounded?: number;
    /**
     * 点击蒙层是否触发关闭事件
     * @default false
     */
    closeWithMask?: boolean;
    /**
     * 蒙层的 className
     */
    maskClassName?: string;
    /**
     * tooltips的 className
     */
    tooltipsClassName?: string;
    /**
     * selector 元素是否可以进行交互
     * @default true
     */
    disableInteraction?: boolean;
    /**
     * tooltip 距离框选节点 / 虚线距离
     * @default 10
     */
    offset?: number;
    /**
     * 节点使用虚线框选
     * @default false
     */
    dashed?: boolean;
    /**
     * step 发生改变时调用
     */
    onStepChange?: (step: number) => void;
    /**
     * 自定义 popper 参数，会被 Steps 中的 popperProps 覆盖
     */
    popperProps?: Partial<IPopperProps>;
    /**
     * 滚动容器
     */
    scroller?: HTMLElement;
}
export interface ISVGMaskProps extends Partial<IGuideProps> {
    currentIndex: number;
    nextStep: () => void;
    close: () => void;
    ref: React.Ref<HTMLDivElement>;
    goTo: (step: number) => void;
}
export interface ISVGMaskState {
    left: number;
    top: number;
    width: number;
    height: number;
    bottom: number;
    right: number;
}
export interface IGuidePopoverCardProps extends IPopoverCardProps {
    /**
     * 标题
     */
    title: React.ReactNode;
    /**
     * 描述
     */
    description?: React.ReactNode;
    /**
     * 显示图标
     * @default true
     */
    showIcon?: boolean;
    /**
     * 自定义 icon 节点
     */
    customIcon?: React.ReactNode;
    /**
     * 显示关闭按钮
     * @default false
     */
    showClose?: boolean;
    /**
     * 点击关闭后的回调
     */
    onClose?: () => void;
}
/**
 * @dts[only]
 */
export declare const Guide: IMuyaPureComponent<IGuideProps, HTMLDivElement, {
    PopoverCard: IMuyaPureComponent<IGuidePopoverCardProps, HTMLDivElement>;
}>;
export {};
