import React, { InputHTMLAttributes } from 'react';
import { ICustomStyleBaseProps, IMuyaPureComponent, IPrefixSuffixNode, ISizeSpecBaseProps, Omit } from '../types';
/**
 * @styles inputWrapper input 容器
 * @styles input input 节点
 */
export declare type IInputNumberStyleKeys = 'inputWrapper' | 'input';
export declare type IInputNumberMode = 'default' | 'plus-minus';
export interface IInputNumberBaseProps extends IPrefixSuffixNode, ISizeSpecBaseProps {
    /**
     * 禁用组件
     *
     * @type {boolean}
     */
    disabled?: boolean;
    /**
     * 获取内部Input的ref
     *
     * @type {(Ref<HTMLInputElement>)}
     */
    inputRef?: React.Ref<HTMLInputElement>;
    /**
     * 展示清除input按钮
     *
     * @type {boolean}
     */
    allowClear?: boolean;
    /**
     * 清空输入框的时候，是否聚焦输入框
     *
     * @type {boolean}
     * @default true
     */
    focusWhenClear?: boolean;
    /**
     * 是否显示边框
     *
     * @type {boolean}
     * @default true
     */
    bordered?: boolean;
}
export interface IInputNumberPureProps extends IInputNumberBaseProps, ICustomStyleBaseProps<IInputNumberStyleKeys> {
    /**
     * value of input
     *
     * @type {string}
     * @memberof IInputProps
     */
    value?: string | number;
    /**
     * defaultValue of input
     *
     * @type {string}
     * @memberof IInputProps
     */
    defaultValue?: string | number;
    /**
     * 指定输入框展示值的格式
     * @memberof IInputPureProps
     */
    formatter?: (value: number | string) => string;
    /**
     * 指定从 formatter 里转换回原格式的方式，和 formatter 搭配使用
     * @memberof IInputPureProps
     */
    parser?: (value: string) => number | string;
    /**
     * 变化事件
     * displayedValue 实时变化；formatterValue 为格式化后的值，只有当触发 onBlur 事件后才一定与 displayedValue 相符
     */
    onChange?: (displayedValue: string, formatterValue: number) => void;
    /**
     *  最小值
     *
     * @type {number}
     * @default -Infinity
     * @memberof IInputProps
     */
    min?: number;
    /**
     *  最大值
     *
     * @type {number}
     * @default Infinity
     * @memberof IInputProps
     */
    max?: number;
    /**
     *  步进器类型
     *
     * @type {IInputNumberType}
     * @default 'default'
     * @memberof IInputProps
     */
    mode?: IInputNumberMode;
    /**
     *  数值精度
     *
     * @type {number}
     * @default 1
     * @memberof IInputProps
     */
    precision?: number;
    /**
     *  固定小数位数，配合`precision`使用，未到足够的精度时自动补0
     *
     * @type {boolean}
     * @default false
     * @memberof IInputProps
     */
    fixPrecision?: boolean;
    /**
     *  每次改变步数，可以为小数
     *
     * @type {number | string}
     * @default 1
     * @memberof IInputProps
     */
    step?: number | string;
    /**
     *  箭头图标大小
     *
     * @type {number}
     * @memberof IInputProps
     */
    iconSize?: number;
    /**
     *  是否常驻隐藏箭头按钮
     *
     * @type {boolean}
     * @default false
     * @memberof IInputProps
     */
    hiddenArrow?: boolean;
    /**
     *  是否显示箭头右边框
     */
    showRightBorder?: boolean;
    /**
     * inputNumber当前状态
     *
     * @type {('loading' | 'success' | 'error')}
     * @memberof IInputProps
     */
    status?: 'loading' | 'success' | 'error';
    /**
     * status存在时，是否显示反馈图标
     *
     * @type {boolean}
     * @default true
     * @memberof IInputProps
     */
    hasFeedback?: boolean;
    /**
     *  是否显示箭头边框
     */
    arrowBordered?: boolean;
    /**
     * 按下回车键的事件
     *
     * @memberof IInputProps
     */
    onPressEnter?: (e: React.KeyboardEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
    /**
     * onBlur 时不触发 onchange 事件
     *  @default false
     *
     * @memberof IInputProps
     */
    disableBlurFormat?: boolean;
}
export declare type IInputNumberProps = IInputNumberPureProps & Omit<InputHTMLAttributes<HTMLInputElement | HTMLTextAreaElement>, 'size' | 'onClick' | 'onMouseLeave' | 'onMouseEnter' | 'onChange' | 'value' | 'defaultValue' | 'min' | 'max'> & Pick<React.HTMLAttributes<HTMLDivElement>, 'onClick' | 'onMouseEnter' | 'onMouseLeave'>;
/**
 * @dts[only]
 */
export declare const InputNumber: IMuyaPureComponent<IInputNumberProps, HTMLDivElement, {
    __MUYA_INPUTNUMBER: true;
}>;
export interface IRangeInputNumberChangeEvent {
    /** 变化的值 */
    value: [string | number, string | number];
}
export declare type IRangeInputNumberInnerProps = Omit<IInputNumberProps, 'size' | 'onClick' | 'value' | 'defaultValue' | 'placeholder' | 'disabled' | 'inputRef' | 'min' | 'max' | 'onPressEnter'>;
/**
 * Input style keys
 * @styles inputWrapper Input外层容器
 * @styles headInput 第一个input
 * @styles tailInput 第二个input
 * @styles nodeDivider suffixNode、prefixNode节点间的分隔符
 */
export declare type IRangeInputNumberStyleKeys = 'inputWrapper' | 'headInput' | 'tailInput' | 'nodeDivider';
export interface IRangeInputNumberPureProps extends Pick<IInputNumberBaseProps, 'disabled' | 'bordered' | 'size'>, ICustomStyleBaseProps<IRangeInputNumberStyleKeys> {
    /**
     * RangeInputNumber的值，必须是长度为2的字符串数组
     */
    value?: string[] | number[];
    /**
     * RangeInputNumber的默认值，必须是长度为2的字符串数组
     */
    defaultValue?: string[] | number[];
    /**
     * RangeInputNumber的placeholder，必须是长度为2的字符串数组
     * @default []
     */
    placeholder?: string[];
    /**
     * 插在中间的节点
     */
    middleNode?: React.ReactNode;
    /**
     * 内部两个input节点的props
     * @typeText
     * Omit<IInputNumberProps,'size'|'onClick'|'value'|'defaultValue'|'placeholder'|'disabled'|'readOnly'|'inputRef'|'min'|'max'|'onPressEnter'
  >
     */
    inputProps?: IRangeInputNumberInnerProps;
    /**
     * 只读
     */
    readOnly?: boolean;
    /**
     * 获取内部Input的ref
     *
     * @type {(Ref<IRangeInputNumberElement>)}
     */
    innerRef?: React.Ref<IRangeInputNumberElement>;
    /**
     * 组件的宽
     *
     * @type {string | number}
     */
    width?: string | number;
    /**
     * 组件的高
     *
     * @type {string | number}
     */
    height?: string | number;
    /**
     * 状态校验
     *
     * @type {'error' | 'success' | 'loading'}
     */
    status?: 'error' | 'success' | 'loading';
    /**
     * 左边输入框的输入限制，[min, max]
     *
     * @type {[number, number]}
     * @default {[-Infinity, Infinity]}
     */
    leftLimit?: [number, number];
    /**
     * 右边输入框的输入限制，[min, max]
     *
     * @type {[number, number]}
     * @default {[-Infinity, Infinity]}
     */
    rightLimit?: [number, number];
    /**
     * 变化事件
     */
    onChange?(displayedValue: string[], formatterValue: number[]): void;
    /**
     * 键盘 enter 事件
     */
    onPressEnter?(displayedValue: string[], formatterValue: number[]): void;
}
export interface IRangeInputNumberBaseElement {
    /** input focus */
    focus(position: 0 | 1, option?: FocusOptions): void;
    /** input blur */
    blur(position: 0 | 1): void;
}
export declare type IRangeInputNumberElement = IRangeInputNumberBaseElement & Omit<HTMLDivElement, 'focus' | 'blur'>;
export declare type IRangeInputNumberProps = IRangeInputNumberPureProps & Pick<InputHTMLAttributes<HTMLInputElement>, 'autoFocus' | 'onKeyDown' | 'onFocus' | 'onBlur'> & Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange' | 'defaultValue' | 'placeholder' | 'onKeyDown' | 'onFocus' | 'onBlur'>;
export declare const RangeInputNumber: IMuyaPureComponent<IRangeInputNumberProps, IRangeInputNumberElement, {
    __MUYA_RANGEINPUTNUMBER: true;
}>;
