import React, { Ref } from 'react';
import { ITagInputAddEvent, ITagInputRenderTagProps } from '../Input';
import { IPopperPlacement } from '../Popper';
import { ITriggerContainerFunc } from '../Trigger';
import { ICommonTriggerProps, ICustomStyleBaseProps, IFormBaseProps, ILabeledValue, IMuyaPureComponent, IPrefixSuffixNode, ISizeSpecBaseProps, Omit } from '../types';
/**
 * Select style keys
 * @styles menu 选项菜单容器
 * @styles menuGroup 菜单项组
 * @styles menuItem 选项菜单项
 * @styles menuDivider 选项菜单分割线
 * @styles inputWrapper 输入框容器
 * @styles input 输入框
 */
export declare type ISelectStyleKeys = 'menu' | 'menuGroup' | 'menuItem' | 'menuDivider' | 'inputWrapper' | 'input';
export declare type ISelectMode = 'default' | 'tags' | 'multiple';
export declare type ISelectSingleValueType = string | number | ILabeledValue;
export declare type ISelectMultiValueType = Array<ISelectSingleValueType>;
export declare type ISelectValueType = ISelectSingleValueType | ISelectMultiValueType | undefined;
export declare type IFilterFunc = (inputValue: string, option: ISelectOptionState) => boolean;
/**
 * 选中可能通过：键盘、焦点、鼠标事件触发
 */
export declare type ISelectSelectTriggerEvent = React.FocusEvent | React.MouseEvent | React.KeyboardEvent;
/**
 * 取消选中可能通过：键盘、点击
 */
export declare type ISelectDeselectTriggerEvent = React.MouseEvent | React.KeyboardEvent;
export interface ISelectOptionState {
    label?: string | number;
    value: string | number;
    disabled?: boolean;
    readOnly?: boolean;
}
export declare type ISelectOptionsState = Record<string, ISelectOptionState>;
export interface IOptionProps {
    /**
     * Option 名，展示用
     */
    label?: string;
    /**
     * Option 值，默认根据此属性值进行筛选
     */
    value: string | number;
    /**
     * Option key，会作为组件
     */
    key?: React.Key;
    /**
     * Option 是否禁用
     */
    disabled?: boolean;
    /**
     * Option 是否只读
     */
    readOnly?: boolean;
    /**
     * Option 的 title，长按会显示原生 tip
     */
    title?: string;
    /**
     * Option 类名
     */
    className?: string;
    /**
     * Option 自定义样式
     */
    style?: React.CSSProperties;
    /**
     * Option 子节点，可以用来自定义 Option 的内容
     */
    children?: React.ReactNode;
}
export interface IOptionGroupProps {
    /**
     * OptionGroup 名，展示用
     */
    label: React.ReactNode;
    /**
     * OptionGroup key，会作为组件
     */
    key?: string;
    /**
     * OptionGroup 类名
     */
    className?: string;
    /**
     * OptionGroup 自定义样式
     */
    style?: React.CSSProperties;
    /**
     * OptionGroup 子节点，可以用来自定义 OptionGroup 的内容
     */
    children: React.ReactElement | React.ReactElement[];
}
export declare type IOptionDividerProps = React.HTMLAttributes<HTMLDivElement>;
export declare type IOptionElement = React.ReactElement<IOptionProps | IOptionGroupProps | IOptionDividerProps>;
export declare type IOptionElements = Array<IOptionElement>;
export interface ISelectBaseProps extends IFormBaseProps<ISelectValueType>, ISizeSpecBaseProps, IPrefixSuffixNode, ICustomStyleBaseProps<ISelectStyleKeys>, ICommonTriggerProps {
    /**
     * SelectInput 是否有边框，仅单选有效
     * @default true
     */
    bordered?: boolean;
    /**
     * 是否允许用户输入列表中不存在的值，并录入，仅单选模式下生效
     */
    combobox?: boolean;
    /**
     * popup 是否显示，结合 `onPopupVisibleChange` 受控使用
     **/
    popupVisible?: boolean;
    /**
     * popup 弹出位置
     * @default 'bottom-start'
     */
    placement?: IPopperPlacement;
    /**
     * popup 延迟关闭
     * @default 0
     **/
    leaveDelay?: number;
    /**
     * 每页最大的 item 数量
     * @default 6.5
     */
    maxItemCountPerPage?: number;
    /**
     * 菜单绑定的节点
     * @default document.body
     **/
    getPopupContainer?: ITriggerContainerFunc;
    /**
     * 点击非 Select 区域的事件回调
     **/
    onClickAway?: (e: React.MouseEvent) => void;
    /**
     * Select 弹出面板显示属性变化的事件回调
     **/
    onPopupVisibleChange?: (open: boolean) => void;
    /**
     * Select 弹出面板滚动的事件回调
     **/
    onPopupScroll?: React.UIEventHandler<HTMLDivElement>;
    /**
     * Select Input 清除按钮点击的事件回调
     **/
    onClear?: React.MouseEventHandler;
    /**
     * Select 选中的事件回调
     **/
    onSelect?: ((value: ISelectOptionState) => void) | ((value: ISelectOptionState[]) => void);
    /**
     * Select 取消选中的回调，仅多选有效
     **/
    onDeselect?: (option: ISelectOptionState, selectedIndex: number) => void;
    /**
     * multiple 和 tags 模式下，tag 的最大数量
     **/
    maxTagCount?: number;
    /**
     * tag 文案最大长度
     **/
    maxTagTextLength?: number;
    /**
     * multiple 和 tags 模式下，Select Input 垂直方向最多显示几行 tag
     * @default 2.5
     */
    maxVerticalTagCount?: number;
    /**
     * tag 最大宽度
     **/
    maxTagWidth?: number;
    /**
     * 自动分词的分隔符，仅在 mode="tags" 时生效
     */
    tokenSeparators?: string[];
    /**
     * 搜索无结果展示的内容
     **/
    notFoundContent?: React.ReactElement;
    /**
     * 是否展示搜索框
     * @default false
     */
    showSearch?: boolean;
    /**
     * 搜索模式下无数据时是否展示无数据样式
     * @default false
     */
    showNoDataWhenSearch?: boolean;
    /**
     * 是否加载中
     * @default false
     */
    loading?: boolean;
    /**
     * 全量 loading，loadingIcon 会整体替换 options，false 时 loadingIcon 会插到 options 下方
     * @default true
     */
    loadingAll?: boolean;
    /**
     * 自定义过滤规则或者禁用过滤规则
     * @default true
     */
    filterOption?: boolean | IFilterFunc;
    /**
     * 搜索的回调
     **/
    onSearch?: (value: string) => void;
    /**
     * 是否保留搜索选中项
     * @default true
     */
    reservedSearchResult?: boolean;
    /**
     * 选择器下拉 icon
     **/
    expandIcon?: React.ReactNode;
    /**
     * 选择器加载 icon
     **/
    loadingIcon?: React.ReactNode;
    /**
     * 选择器选中 icon
     **/
    selectedIcon?: React.ReactNode;
    /**
     * 自定义清空的 icon
     */
    clearIcon?: React.ReactNode;
    /**
     * 传给 DOM 节点的 id
     **/
    id?: string;
    /**
     * label 放入 value 中返回
     * @default false
     */
    labelInValue?: boolean;
    /**
     * 选择器模式
     * @default 'default'
     */
    mode?: ISelectMode;
    /**
     * 选项显示 checkbox，通过 checkbox 进行选中和取消选中
     */
    checkable?: boolean;
    /**
     * 子节点
     * @typeText
     */
    children: IOptionElement | IOptionElements;
    /**
     * 面板宽度
     **/
    width?: number | string;
    /**
     * popup 宽度
     **/
    popupWidth?: number;
    /**
     * 覆盖默认的 Input 节点
     **/
    getInputElement?: () => React.ReactElement;
    /**
     * 选中值改变的回调
     **/
    onChange?: (value: ISelectValueType) => void;
    /**
     * 回填
     * @default false
     */
    backfill?: boolean;
    /**
     * 隐藏展开 icon
     * @default false
     */
    hideExpandIcon?: boolean;
    /**
     * 是否默认选中第一个 option
     * @default false
     */
    defaultActiveFirstOption?: boolean;
    /**
     * select 内部 input 的 ref
     */
    inputRef?: Ref<HTMLInputElement>;
    /**
     * 弹出菜单的 ref
     */
    menuRef?: React.RefObject<HTMLDivElement>;
    /**
     * 根据内容自适应宽度
     * @default false
     */
    autoResize?: boolean;
    /**
     * 多选，自定义 Tag 的渲染，建议基于 InputTag 进行自定义
     */
    renderTag?: (props: ITagInputRenderTagProps) => React.ReactNode;
    /**
     * 此项设置为 true 时，clear 替换最后一个节点
     *
     * @type {boolean}
     * @memberof IInputProps
     */
    clearReplace?: boolean;
    /**
     * 多选 Input 开启水平滚动
     */
    horizontalScroll?: boolean;
    /**
     * 自定义下拉框内容
     */
    dropdownRender?: (originNode: JSX.Element) => JSX.Element;
}
export declare type ISelectProps = ISelectBaseProps & Omit<React.HTMLAttributes<HTMLInputElement>, 'size' | 'value' | 'defaultValue' | 'onSelect' | 'onChange'>;
export interface ISelectInputBaseProps extends IFormBaseProps<ISelectValueType>, ISizeSpecBaseProps, IPrefixSuffixNode, ICustomStyleBaseProps<ISelectStyleKeys> {
    /**
     * 传给 DOM 节点的 id
     **/
    id?: string;
    /**
     * 占位文案
     **/
    placeholder: string;
    /**
     * SelectInput 是否有边框，仅单选有效
     * @default true
     */
    bordered?: boolean;
    /**
     * multiple 和 tags 模式下，tag 的最大数量
     **/
    maxTagTextLength?: number;
    /**
     * multiple 和 tags 模式下，Select Input 垂直方向最多显示几行 tag
     * @default 2.5
     */
    maxVerticalTagCount: number;
    /**
     * tag 最大宽度
     **/
    maxTagWidth?: number;
    /**
     * 是否显示搜索框
     **/
    showSearch: boolean;
    /**
     * 搜索回调
     **/
    onSearch?: (value: string) => void;
    /**
     * 展开 icon
     **/
    expandIcon?: React.ReactNode;
    /**
     * Select Input 输入框值
     **/
    inputValue: string;
    /**
     * Select 面板弹出状态
     **/
    popupVisible: boolean;
    /**
     * 选中状态
     **/
    value: ISelectMultiValueType;
    /**
     * 所有的 options
     **/
    allOptions: ISelectOptionsState;
    /**
     * 是否多选
     **/
    isMultiple: boolean;
    /**
     * 是否有选中值
     **/
    hasValue: boolean;
    /**
     * 清除按钮点击回调
     **/
    onClear: React.MouseEventHandler;
    /**
     * 选择回调
     **/
    onSelect: (value: ISelectOptionState, popupVisible: boolean, e?: ISelectSelectTriggerEvent) => void;
    /**
     * 取消选择回调
     **/
    onDeselect: (option: ISelectOptionState, selectedIndex: number, e?: ISelectDeselectTriggerEvent) => void;
    /** 输入框输入事件 */
    onInput?: React.FormEventHandler<HTMLInputElement>;
    /**
     * 键盘按下的事件回调
     */
    onKeyDown?: React.KeyboardEventHandler<HTMLInputElement>;
    /**
     * 输入框内容变更的回调
     **/
    onInputChange: (value: string) => void;
    /**
     * 添加 tag
     **/
    onAddTag: (value: string | string[], e?: ITagInputAddEvent) => void;
    /**
     * 模式：'default' | 'multiple' | 'tags'
     * @default 'default'
     **/
    mode: ISelectMode;
    /**
     * 传入和输出是否为 labelInValue
     **/
    labelInValue: boolean;
    /**
     * 选择器宽度
     **/
    width?: number | string;
    /**
     * 覆盖默认的控制节点
     **/
    getInputElement?: () => React.ReactElement;
    /**
     * 回填
     **/
    backfill: boolean;
    /**
     * 隐藏展开按钮
     **/
    hideExpandIcon: boolean;
    /**
     * select 内部 input 的 ref
     */
    inputRef?: React.Ref<HTMLInputElement>;
    /**
     * 根据内容自适应宽度
     */
    autoResize: boolean;
    /**
     * 是否显示 Menu
     */
    showMenu: boolean;
    /**
     * 弹出菜单的 ref
     */
    menuRef: React.RefObject<HTMLDivElement>;
    /**
     * 是否可自由输入
     */
    combobox: boolean;
    /**
     * 多选，自定义 Tag 的渲染，建议基于 InputTag 进行自定义
     */
    renderTag?: (props: ITagInputRenderTagProps) => React.ReactNode;
    /**
     * 此项设置为 true 时，clear 替换最后一个节点
     *
     * @type {boolean}
     * @memberof IInputProps
     */
    clearReplace?: boolean;
    /**
     * 多选 Input 开启水平滚动
     */
    horizontalScroll?: boolean;
    /**
     * 自动分词的分隔符，仅在 mode="tags" 时生效
     */
    tokenSeparators?: string[];
}
export declare type ISelectInputProps = ISelectInputBaseProps & Omit<React.HTMLAttributes<HTMLInputElement>, 'onSelect' | 'onInput' | 'onChange' | 'value' | 'defaultValue' | 'size'>;
/**
 * @dts[only]
 */
export declare const Option: React.FunctionComponent<IOptionProps>;
export declare const OptionGroup: React.FunctionComponent<IOptionGroupProps>;
export declare const OptionDivider: React.FunctionComponent<IOptionDividerProps>;
export declare const Select: IMuyaPureComponent<ISelectProps, HTMLDivElement, {
    __MUYA_SELECT: true;
    Option: typeof Option;
    OptionGroup: typeof OptionGroup;
    OptionDivider: typeof OptionDivider;
}>;
