import { ITooltipProps } from '../Tooltip';
import { ITheme } from '@muya-ui/theme-light';
import React from 'react';
import { DefaultTheme, StyledComponent } from 'styled-components';
import { IButtonStyleKeys, IButtonType, IInlineButtonPureProps } from '../Button';
import { ISwipeBaseProps } from '../Swipe';
import { ICustomStyleBaseProps, IMuyaPureComponent, ISizeSpecBaseProps, Omit } from '../types';
import { IBadgeProps } from '../Badge';
export declare type ITabsType = 'line' | 'card' | 'capsule';
export declare type ITabsPosition = 'top' | 'bottom' | 'left' | 'right';
/**
 * @styles wrapper 包裹 Tabs 和 Panel 的容器
 * @styles container 容器
 * @styles indicator 指示器
 * @styles extraContentWrapper 额外元素的容器
 * @styles panel 使用TabPanel且type为fade的TabPanel的容器
 * @styles swipePanel 使用TabPanel且type为swipe的TabPanel的容器
 * @styles tab 选项卡
 * @styles activeTab 选中状态的选项卡
 */
export declare type ITabsStyleKeys = 'wrapper' | 'container' | 'indicator' | 'extraContentWrapper' | 'panel' | 'swipePanel' | 'tab' | 'activeTab';
declare type IPropsFromSwipeBaseProps = Pick<ISwipeBaseProps, 'enableDiffChildren' | 'equalNum' | 'gutter' | 'duration'>;
declare type IPropsFromInlineButtonPureProps = Pick<IInlineButtonPureProps, 'busy' | 'disabled' | 'size'>;
export interface ITabsPureProps extends ICustomStyleBaseProps<ITabsStyleKeys>, IPropsFromSwipeBaseProps, IPropsFromInlineButtonPureProps {
    /**
     * Tabs类型
     * @default 'line'
     */
    type?: ITabsType;
    /** Tabs高度，如果你需要文字水平居中 */
    height?: number;
    /** 当前所在索引位置 */
    index?: string | number;
    /**
     * 默认的 index
     * 0
     */
    defaultIndex?: string | number;
    /** 关闭翻页功能，在使容器居中时使用 */
    swipe?: boolean;
    /** 变化的事件 */
    onChange?: (value: string | number) => void;
    /** Tabs右边添加附加操作节点 */
    tabBarExtraContent?: React.ReactNode;
    /**
     * line 模式下，指示器模式
     * * 'default': 默认
     * * 'static': 静态
     * * 'none': 不显示
     */
    lineIndicatorMode?: 'default' | 'static' | 'none';
    /**
     * 火柴棍模式下底部指示器宽度，不传跟tab等宽
     * */
    tabLineIndicatorWidth?: number;
    /**
     *  如果使用了 TabPanel, 将会控制 TabPanel 切换时的动画
     *  @default 'static'
     */
    panelAnimation?: 'static' | 'swipe' | 'fade';
    /**
     * 切换时 TabPanel 是否保持 mount
     * * false: 每次打开都会重新 mount
     * * true: 只在 Tabs 初始化的时候 mount 一次
     * * 'lazy': 只在第一次切换到该 tab 时 mount 一次
     *
     * @default panelAnimation为swipe时为true，其他为false
     */
    panelKeepMounted?: boolean | 'lazy';
    /**
     * panelKeepMounted 开启的状态下一些依赖计算属性的组件
     * (Img, ImgPreview, Swipe, Slider)会出现
     * 计算值不正确的情况,开启此属性后会延迟计算一次
     *
     * @default false
     */
    panelTriggerResize?: boolean;
    /**
     * 位置，对于 tabPanel 的模式实际有效，对于纯 tab 的模式仅会修改 tab 的方向
     * @default 'top'
     */
    tabPosition?: ITabsPosition;
}
/**
 * @styles item 按钮
 * @styles suffix 后缀节点
 * @styles prefix 前缀节点
 */
export declare type ITabStyleKeys = 'item' | IButtonStyleKeys;
export interface ITabPureProps extends ICustomStyleBaseProps<ITabStyleKeys>, Omit<IInlineButtonPureProps, 'type' | 'styles' | 'weakLevel'> {
    /**
     * Tabs类型
     * @default 'line'
     */
    type?: ITabsType;
    /**
     * 设置常态下，内部inlineButton的type
     *
     * @type {IButtonType}
     * @memberof ITabPureProps
     */
    buttonType?: IButtonType;
    /**
     * 索引名
     */
    index?: string | number;
    /**
     * 是否选中
     */
    selected?: boolean;
    /**
     * 显示分割符badgePatchCss
     *
     *
     *
     */
    divider?: 'off';
    /**
     * a 标签的属性，透传到button上，有这个属性会使用 dom a标签
     */
    href?: React.AnchorHTMLAttributes<HTMLAnchorElement>['href'];
    /**
     * a 标签的属性，透传到button上
     */
    target?: React.AnchorHTMLAttributes<HTMLAnchorElement>['target'];
    /**
     * a 标签的属性，透传到button上
     */
    rel?: React.AnchorHTMLAttributes<HTMLAnchorElement>['rel'];
    /**
     * 仅在火柴棍型且 lineIndicatorMode 为 static 时有效，表示是否显示 selected 后底部的指示器的条
     * @default false
     */
    showIndicator?: boolean;
    /**
     * 传入了 tooltipProps 则会开启当前 tab 的 tooltip 并传入该 props
     */
    tooltipProps?: Omit<ITooltipProps, 'children'>;
    /**
     * 传入了 badgeProps 则会开启当前 tab 的 badge 并传入该 props
     */
    badgeProps?: Omit<IBadgeProps, 'children'>;
    /**
     * 位置，对于 tabPanel 的模式实际有效，对于纯 tab 的模式仅会修改 tab 的方向
     * @default 'top'
     */
    tabPosition?: ITabsPosition;
}
export interface ITabsContainerPureProps extends ISizeSpecBaseProps, IPropsFromSwipeBaseProps {
    /**
     * Tabs类型
     */
    type: ITabsType;
    /**
     * 关闭翻页功能
     */
    swipe?: boolean;
    /**
     * Tabs高度，如果你需要文字水平居中
     */
    height?: number;
    /**
     * 当前选中的 tab 下标
     */
    selectedIndex?: number;
    onChange?: (offset?: number) => void;
    /**
     * 是否开启了 badge
     */
    enableBadge?: boolean;
    /**
     * 垂直布局
     */
    vertical: boolean;
}
/**
 *
 * @include
 */
export interface ITabPanelPureProps {
    /**
     * tab按钮显示的内容
     */
    tab: React.ReactNode;
    /**
     * 索引名称
     *
     */
    index: string | number;
    /**
     * 传递进入tab按钮的props，参见ITabProps
     *
     * @typeText ITabProps
     */
    tabProps?: Omit<ITabProps, 'index'>;
}
export interface IPanelItemProps {
    visible: boolean;
    type: 'fade' | 'static' | 'swipe';
    theme: DefaultTheme;
    keepMounted: boolean | 'lazy';
}
export declare type ITabsProps = ITabsPureProps & Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange'>;
export declare type ITabProps = ITabPureProps & React.HTMLAttributes<HTMLDivElement>;
export declare type ITabsContainerProps = ITabsContainerPureProps & Omit<React.HTMLAttributes<HTMLDivElement>, 'onChange'>;
export declare type ITabPanelProps = ITabPanelPureProps & React.HTMLAttributes<HTMLDivElement>;
export declare type ITypedTabsProps = ITabsProps & {
    enableBadge: boolean;
    vertical: boolean;
};
/**
 * @dts[only]
 */
export declare const Tab: StyledComponent<IMuyaPureComponent<ITabProps, HTMLDivElement>, ITheme, ITabProps>;
export declare const TabPanel: IMuyaPureComponent<ITabPanelProps, HTMLDivElement, {
    __MUYA_TABPANEL: true;
}>;
export declare const Tabs: StyledComponent<IMuyaPureComponent<ITabsProps, HTMLDivElement>, ITheme, ITabsProps> & {
    Tab: typeof Tab;
    TabPanel: typeof TabPanel;
};
export {};
