import React from 'react';
import { IInputProps } from '../Input';
import { ICustomStyleBaseProps, ICustomStyleItem } from '../types';
import useTransferTree from './useTransferTree';
export interface ITransferItem {
    key: string;
    disabled?: boolean;
    title?: string;
}
export declare type ITransferMode = 'move' | 'copy';
export declare type ITransferDirection = 'left' | 'right';
export declare type ITransferOrder = 'DESC' | 'ASC';
export declare type ITransferChange = (nextTargetKeys: string[], nextSourceKeys: string[], actionDirection: ITransferDirection, transferKey: string[]) => void;
export declare type ITransferStyleKeys = 'container' | 'leftPanel' | 'rightPanel' | 'leftHeader' | 'rightHeader' | 'leftFoot' | 'rightFoot';
export interface ITransferRenderProps<T> {
    /**
     * 所处面板位置
     */
    direction: ITransferDirection;
    /**
     * 搜索完成后还显示的条目
     */
    filteredItems: T[];
    /**
     * 搜索完成后还显示的条目的key的集合
     */
    filteredItemKeys: string[];
    /**
     * 默认的点击触发事件
     */
    onItemSelect: (key: string) => void;
}
export interface ITransferPropsPure<T> extends ICustomStyleBaseProps<ITransferStyleKeys> {
    /**
     *  数据源，默认展示 title 字段，通过 renderItem 方法自定义展示字段
     */
    dataSource: T[];
    /**
     * 被选中的数据的 key 的集合
     */
    targetSource?: string[];
    /**
     * 默认被选中的数据的 key 的集合
     */
    defaultTargetSource?: string[];
    /**
     * 数据移动时插入的位置，默认为倒序插入
     * @default 'DESC'
     * @type {'DESC' | 'ASC'}
     */
    order?: ITransferOrder;
    /**
     * 自定义展示规则
     */
    renderItem?: (record: T) => React.ReactNode;
    /**
     * 标题集合，顺序从左至右
     * @default ['', '']
     */
    titles?: [React.ReactNode, React.ReactNode];
    /**
     * 是否显示数量统计
     * @default true
     */
    showCount?: boolean;
    /**
     * 头部最右侧额外节点
     */
    headerExtraNode?: [React.ReactNode, React.ReactNode];
    /**
     * 穿梭框模式，分为“点击即移动”与“点击即复制”
     * @default 'move'
     */
    mode?: ITransferMode;
    /**
     * 是否显示搜索框或只在一侧显示搜索框
     * @default false
     */
    showSearch?: boolean | ITransferDirection;
    /**
     * 自定义搜索方式，返回true展示该条内容，返回false不展示该条内容
     */
    filterOption?: (inputValue: string, option: T) => boolean;
    /**
     * 搜索框内容时改变时的回调函数，用于触发 search 时提供 hook，不建议在这个方法里对搜索进行受控，自定义搜索功能建议使用 filterOption
     */
    onSearch?: (direction: ITransferDirection, value: string) => void;
    /**
     * 搜索框占位字符
     * @default ['搜索', '搜索']
     */
    searchPlaceholder?: [string | undefined, string | undefined];
    /**
     * 底部动作条集合，顺序从左至右
     */
    footer?: [React.ReactNode, React.ReactNode];
    /**
     * 自定义中间的icon图标节点
     */
    transferIcon?: React.ReactNode;
    /**
     * 发生穿梭动作时触发，回调入参
     *
     * 1. nextTargetKeys: 移动完成后右侧面板的数据
     *
     * 2. nextSourceKeys: 移动完成后左侧面板的数据
     *
     * 3. actionDirection: 移动发生的所在的面板（点击的面板）
     *
     * 4. transferKey: 发生移动的item的key
     */
    onChange?: ITransferChange;
    /**
     * 自定义全选框点击事件
     */
    onCopyAll?: (filteredItems: T[]) => void;
    /**
     * 是否展示全选勾选框(只在 mode 为 copy 时有效)
     * @default true
     */
    showSelectAll?: boolean;
    /**
     * 	显示在右侧面板的每条 item 最右侧的额外内容、图标（默认复制模式下会有个垃圾桶图标）
     */
    rightItemExtra?: React.ReactNode;
    /**
     * render props
     * 详见 ITransferRenderProps
     */
    children?: (props: ITransferRenderProps<T>) => React.ReactNode;
    /**
     * 两个面板容器的 ref，如果只需要一个，就给另一个传 undefined 或不传
     */
    panelRef?: [React.Ref<HTMLDivElement> | undefined, React.Ref<HTMLDivElement> | undefined];
    /**
     * 两个面板容器的 onScroll 事件，如果只需要一个，就给另一个传 undefined 或不传
     */
    panelOnScroll?: [React.UIEventHandler<HTMLDivElement> | undefined, React.UIEventHandler<HTMLDivElement> | undefined];
    /**
     * 搜索框的props覆盖
     * @type {IInputProps}
     */
    searchProps?: IInputProps;
    /**
     * 数据为空时的空页面
     */
    emptyNode?: React.ReactNode | [React.ReactNode, React.ReactNode];
}
export declare type ITransferProps<T> = ITransferPropsPure<T>;
export interface ITransferPanelProps<T> extends Pick<ITransferPropsPure<T>, 'renderItem' | 'showCount' | 'mode' | 'showSearch' | 'onSearch' | 'showSelectAll' | 'rightItemExtra' | 'rightItemExtra' | 'searchProps' | 'panelRef' | 'panelOnScroll'> {
    direction: ITransferDirection;
    items: T[];
    title: React.ReactNode;
    handleClick: (key: string) => void;
    searchPlaceholder: string;
    footer: React.ReactNode;
    rightItems?: T[];
    leftActionCopyAll?: (filteredItems: T[]) => void;
    children?: (props: ITransferRenderProps<T>) => React.ReactNode;
    containerStyles?: ICustomStyleItem;
    headerStyles?: ICustomStyleItem;
    footStyles?: ICustomStyleItem;
    filterOption?: (inputValue: string, option: T) => boolean;
    emptyNode?: React.ReactNode;
    headerExtraNode?: React.ReactNode;
    scrollContainerRef?: React.Ref<HTMLDivElement>;
    onScroll?: React.UIEventHandler<HTMLDivElement>;
}
export interface ITransferIconProps {
    mode: ITransferMode;
}
export declare type ITransferPure = <T extends ITransferItem = ITransferItem>(props: ITransferProps<T> & {
    ref?: React.Ref<HTMLDivElement>;
}) => React.ReactElement;
export declare type ITransfer = ITransferPure & {
    useTransferTree: typeof useTransferTree;
};
