import React, { Ref, RefObject } from 'react';
import { ICustomStyleBaseProps, ISizeSpecBaseProps, Omit } from '../types';
/**
 * Tree style keys
 * @styles node 树节点
 * @styles selectedNode 选中的树节点
 * @styles checkedNode check 的树节点
 * @styles nodeContent 树节点内容
 * @styles nodeSelector 树节点选择区
 * @styles nodeIconWrapper树节点 Icon 容器
 * @styles nodeTitle 树节点标题
 * @styles childTree 子树
 */
export declare type ITreeNodeStyleKeys = 'node' | 'selectedNode' | 'checkedNode' | 'nodeContent' | 'nodeSelector' | 'nodeIconWrapper' | 'nodeTitle' | 'childTree';
/**
 * Tree style keys
 * @styles scrollWrapper 开启 scrollable 时在外层滚动容器节点
 * @styles 树容器
 */
export declare type ITreeStyleKeys = 'scrollWrapper' | 'wrapper';
/** Tree 节点的 key */
export declare type ITreeNodeKey = string | number;
/** 树选中行为触发点 */
export declare enum CheckEventTrigger {
    Checkbox = "Checkbox",
    TreeNode = "TreeNode"
}
/** 树展开行为触发点 */
export declare enum ExpandEventTrigger {
    ExpandIcon = "ExpandIcon",
    TreeNode = "TreeNode"
}
export interface ITreeAllowDropOptions<T extends ITreeNodeData = ITreeNodeData> {
    dragNode: ITreeNodeEventData<T>;
    dropNode: ITreeNodeEventData<T>;
    dropPosition: -1 | 0 | 1;
}
export declare type ITreeAllowDrop<T extends ITreeNodeData = ITreeNodeData> = (options: ITreeAllowDropOptions<T>) => boolean;
export interface ITreeFieldNamesType {
    key?: string;
    title?: string;
    children?: string;
    isLeaf?: string;
}
export interface ITreeFilledFieldNamesType {
    key: string;
    title: string;
    children: string;
    isLeaf: string;
}
export interface IFlattenNode<T extends ITreeNodeData = ITreeNodeData> {
    parent: IFlattenNode<T> | null;
    children: IFlattenNode<T>[];
    pos: string;
    data: T;
    lastChildFlags: boolean[];
}
export interface ITreeNodeDataEntity<T extends ITreeNodeData = ITreeNodeData> {
    index: number;
    key: ITreeNodeKey;
    pos: string;
    node: T;
    parent?: ITreeNodeDataEntity<T>;
    children?: ITreeNodeDataEntity<T>[];
    level: number;
}
export interface ITreeState<T extends ITreeNodeData = ITreeNodeData> {
    keyEntities: Record<ITreeNodeKey, ITreeNodeDataEntity<T>>;
    selectedKeys: ITreeNodeKey[];
    checkedKeys: ITreeCheckedKeysObject;
    loadKeys: ITreeLoadKeysObject;
    expandedKeys: ITreeNodeKey[];
    dragging: boolean;
    dragNodesKeys: ITreeNodeKey[];
    dragOverNodeKey: ITreeNodeKey | null;
    dropPosition: number | null;
    dropLevelOffset: number;
    treeData: T[];
}
export interface ITreeContextValue<T extends ITreeNodeData = ITreeNodeData> extends Omit<ITreeState<T>, 'dragging' | 'dragNodesKeys'>, Pick<ITreeProps<T>, 'loadData' | 'renderNodeContent' | 'size' | 'renderNodeRightArea' | 'disabled' | 'notLeafCheckable' | 'checkable' | 'selectable' | 'draggable' | 'icon' | 'expandIcon' | 'expandOnClick' | 'checkOnClick' | 'showLine' | 'disableNativeTitle' | 'renderAfterExpand' | 'renderCheckbox' | 'virtual'> {
    onNodeTransitionEnd: () => void;
    onNodeDragStart: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDragEnd: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDragEnter: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDragOver: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDragLeave: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDrop: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeClick: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeDoubleClick: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeSelect: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeCheck: (event: React.SyntheticEvent, eventData: ITreeNodeEventData<T>, trigger: CheckEventTrigger) => void;
    onNodeExpand: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>, trigger: ExpandEventTrigger) => void;
    onNodeMouseEnter: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeMouseLeave: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeContextMenu: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    onNodeLoad: (eventData: ITreeNodeEventData<T>) => void;
}
export interface IUseTreeProps<T extends ITreeNodeData = ITreeNodeData> extends ITreeContextValue<T> {
    transitionType: 'show' | 'hide' | null;
    transitionNodes: IFlattenNode<T>[];
    list: Array<{
        data: IFlattenNode<T>;
        index: number;
    }>;
    containerProps: {
        ref: (ele: any) => void;
        onScroll: (e: React.UIEvent<Element>) => void;
        style: React.CSSProperties;
    };
    wrapperProps: {
        style: React.CSSProperties;
    };
    handleScroll: (e: React.UIEvent<Element>) => void;
}
export interface ITreeNodeState {
    /**
     * 是否 hover
     */
    hovering: boolean;
    /**
     * 节点展开状态
     */
    expanded: boolean;
    /**
     * 节点选则状态
     */
    selected: boolean;
    /**
     * 节点加载状态
     */
    loaded: boolean;
    /**
     * 节点加载中状态
     */
    loading: boolean;
    /**
     * 节点选中状态
     */
    checked: boolean;
    /**
     * 节点半选状态
     */
    halfChecked: boolean;
    /**
     * 节点位置
     */
    pos: string;
    /**
     * 是否有节点放置
     */
    dragOver: boolean;
    /**
     * 是否有节点放到上面
     */
    dragOverGapTop: boolean;
    /**
     * 是否有节点放到下面
     */
    dragOverGapBottom: boolean;
}
/** TreeIcon */
export declare type ITreeIconType<T extends ITreeNodeData = ITreeNodeData> = React.ReactNode | ((props: ITreeNodeProps<T> & ITreeNodeState) => React.ReactNode);
/** Tree Checkbox 的 Key 类型 */
export interface ITreeCheckedKeysObject {
    checked: ITreeNodeKey[];
    halfChecked: ITreeNodeKey[];
}
export declare type ITreeCheckedKeys = ITreeNodeKey[] | ITreeCheckedKeysObject;
export interface ITreeLoadKeysObject {
    loaded: ITreeNodeKey[];
    loading: ITreeNodeKey[];
}
/** Tree 数据节点：用户输入 */
export interface ITreeNodeData {
    /** 节点是否可选中 */
    checkable?: boolean;
    /** 节点是否可选择 */
    selectable?: boolean;
    /** 是否可以被拖拽 */
    draggable?: boolean;
    /** 子节点 */
    children?: ITreeNodeData[];
    /** 节点是否禁用 */
    disabled?: boolean;
    /** 节点 Checkbox 是否禁止 */
    disableCheckbox?: boolean;
    /** 是否为叶子节点 */
    isLeaf?: boolean;
    /** 节点唯一 key */
    key?: ITreeNodeKey;
    /** 节点标题 */
    title?: React.ReactNode;
    /** 节点 Icon */
    icon?: ITreeIconType;
    /**
     * 节点展开的 Icon
     * @typeText
     * React.ReactNode | ((props: ITreeNodeProps & ITreeNodeState) => React.ReactNode)
     */
    expandIcon?: ITreeIconType;
    /** 自定义参数 */
    [customProp: string]: any;
}
export interface ITreeCheckInfo<T extends ITreeNodeData = ITreeNodeData> {
    /** check 事件数据 */
    data: ITreeNodeEventData<T>;
    /** 选中状态 */
    checked: boolean;
    /** 触发选中行为的触发点 */
    trigger: CheckEventTrigger;
    /** 原生事件 */
    nativeEvent: Event;
    /** 选中的节点 */
    checkedNodes: T[];
    /** 选中的节点位置 */
    checkedNodesPositions?: {
        node: T;
        pos: string;
    }[];
    /** 半选的节点 Key */
    halfCheckedKeys?: ITreeNodeKey[];
}
export interface ITreeExpandInfo<T extends ITreeNodeData = ITreeNodeData> {
    /** 展开事件数据 */
    data: ITreeNodeEventData<T>;
    /** 展开状态 */
    expanded: boolean;
    /** 触发展开行为的触发点 */
    trigger: ExpandEventTrigger;
    /** 原生事件 */
    nativeEvent: Event;
}
export interface ITreeSelectInfo<T extends ITreeNodeData = ITreeNodeData> {
    /** 选择事件数据 */
    data: ITreeNodeEventData<T>;
    /** 选择状态 */
    selected: boolean;
    /** 原生事件 */
    nativeEvent: Event;
}
/**
 * TreeNode 的 Event 数据
 **/
export interface ITreeNodeEventData<T extends ITreeNodeData = ITreeNodeData> extends ITreeNodeData, ITreeNodeState {
    /** 节点 Key */
    nodeKey: ITreeNodeKey;
    /** 节点数据 */
    data: T;
    /** 节点 ref */
    nodeRef: RefObject<HTMLDivElement>;
}
export interface ITreeNodeBaseProps<T extends ITreeNodeData = ITreeNodeData> extends ITreeNodeData, ICustomStyleBaseProps<ITreeNodeStyleKeys> {
    /** 节点 Key */
    nodeKey: ITreeNodeKey;
    /** 节点数据 */
    data: T;
    /** 节点 ref */
    nodeRef?: Ref<HTMLLIElement>;
    /** 是否为当前子树的最后一个子节点 */
    lastChildFlags?: boolean[];
}
export declare type ITreeNodeProps<T extends ITreeNodeData = ITreeNodeData> = ITreeNodeBaseProps<T> & Omit<React.HTMLAttributes<HTMLLIElement>, 'children' | 'title'>;
export interface ITransitionTreeNodeProps<T extends ITreeNodeData = ITreeNodeData> extends ITreeNodeProps<T> {
    /** 动画类型 */
    transitionType: 'show' | 'hide' | null;
    /** 动画的节点 */
    transitionNodes: IFlattenNode<T>[];
    /** 动画结束的回调 */
    onTransitionEnd: () => void;
    /**
     * 是否是当前子树的最后一个节点
     */
    lastChildFlags: boolean[];
}
export interface ITreeCheckboxProps {
    checked: boolean;
    halfChecked: boolean;
    disabled: boolean;
    disableCheckbox?: boolean;
    onCheck: (e: React.SyntheticEvent) => void;
}
export interface ITreeBaseProps<T extends ITreeNodeData = ITreeNodeData> extends ICustomStyleBaseProps<ITreeStyleKeys | ITreeNodeStyleKeys>, ISizeSpecBaseProps {
    /**
     * 是否开启虚拟列表优化
     * @default false
     */
    virtual?: boolean;
    /** 树的 ref */
    treeRef?: Ref<HTMLUListElement>;
    /**
     * 树溢出是否可滚动，默认不可滚动，采用省略文本策略
     * @default false
     */
    scrollable?: boolean;
    /**
     * 自定义 treeData 中 key、title、children、isLeaf 的键名
     * @default { key: 'key', title: 'title', 'children': 'children', isLeaf: 'isLeaf' }
     **/
    fieldNames?: ITreeFieldNamesType;
    /**
     * 请使用 fieldNames 代替，大版本将移除
     **/
    customKeyName?: string;
    /**
     * 请使用 fieldNames 代替，大版本将移除
     **/
    customTitleName?: string;
    /**
     * 请使用 fieldNames 代替，大版本将移除
     **/
    customChildrenName?: string;
    /** 树节点 Icon */
    icon?: ITreeIconType<T>;
    /**
     * 树节点展开的 Icon
     * @typeText
     * React.ReactNode | ((props: ITreeNodeProps & ITreeNodeState) => React.ReactNode)
     */
    expandIcon?: ITreeIconType<T>;
    /**
     * 是否显示连接线
     * @default false
     **/
    showLine?: boolean;
    /**
     * 点击并展开
     * @default false
     **/
    expandOnClick?: boolean;
    /**
     * 点击并选中
     * @default false
     **/
    checkOnClick?: boolean;
    /**
     * 展开后才渲染子节点，树节点数量较大时请将此参数设为 `true`，虚拟列表模式下无效。
     * @default false
     **/
    renderAfterExpand?: boolean;
    /** 自定义子节点内容渲染（不包含展开 Icon、Checkbox 和 Icon） */
    renderNodeContent?: (props: ITreeNodeProps<T> & ITreeNodeState) => React.ReactNode;
    /** 自定义子节点右侧内容的渲染，通常是一些操作的行动点 */
    renderNodeRightArea?: (props: ITreeNodeProps<T> & ITreeNodeState) => React.ReactNode;
    /** 自定义开启 checkable 后，子节点的 Checkbox 节点 */
    renderCheckbox?: (props: ITreeCheckboxProps & T) => React.ReactNode;
    /** 子节点 */
    children?: React.ReactNode;
    /** 节点点击 */
    onClick?: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    /** 节点双击 */
    onDoubleClick?: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    /** 鼠标进入节点 */
    onMouseEnter?: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    /** 鼠标离开节点 */
    onMouseLeave?: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    /** 节点右击 */
    onRightClick?: (event: React.MouseEvent, eventData: ITreeNodeEventData<T>) => void;
    /**
     * 禁用整个树
     * @default false
     **/
    disabled?: boolean;
    /**
     * 是否多选
     * @default false
     **/
    multiple?: boolean;
    /** 树节点数据 */
    data: Array<T>;
    /** 过滤后的 treeData，当 data 和 filterTreeData 同时设置时，计算选中等会使用全量数据，渲染使用 filterTreeData 数据 */
    filterTreeData?: Array<T>;
    /**
     * 禁用原生的 title，在自定义节点的 Tooltip 时可通过此属性禁用原生的 Title 属性
     * @default false
     */
    disableNativeTitle?: boolean;
    /**
     * 是否可选择
     * @default true
     **/
    selectable?: boolean;
    /** 选择的 Keys */
    selectedKeys?: ITreeNodeKey[];
    /**
     * 默认选择的 Keys
     * @default []
     **/
    defaultSelectedKeys?: ITreeNodeKey[];
    /** 选择的事件 */
    onSelect?: (selectedKeys: ITreeNodeKey[], info: ITreeSelectInfo<T>) => void;
    /** 展开的 Keys */
    expandedKeys?: ITreeNodeKey[];
    /**
     * 是否自动展开父节点（受控）
     **/
    autoExpandParent?: boolean;
    /**
     * 默认展开父节点
     * @default true
     */
    defaultExpandParent?: boolean;
    /**
     * 默认展开的 Keys
     * @default []
     **/
    defaultExpandedKeys?: ITreeNodeKey[];
    /**
     * 默认展开所有树节点
     * @default false
     **/
    defaultExpandAll?: boolean;
    /** 展开的事件 */
    onExpand?: (expandedKeys: ITreeNodeKey[], info: ITreeExpandInfo<T>) => void;
    /**
     * 节点前添加 Checkbox 复选框
     * @default false
     **/
    checkable?: boolean;
    /**
     * 非叶子节点是否可选中（仅 checkable 启用时有效，用于快速关闭非叶子节点的选中）
     * @default true
     */
    notLeafCheckable?: boolean;
    /** 选中的 Keys */
    checkedKeys?: ITreeCheckedKeys;
    /**
     * 默认选中的 Keys
     * @default []
     **/
    defaultCheckedKeys?: ITreeCheckedKeys;
    /**
     * checkable 状态下节点选择完全受控（父子节点选中状态不再关联）
     * @default false
     **/
    checkStrictly?: boolean;
    /** 选中的事件 */
    onCheck?: (checkedKeys: ITreeCheckedKeys, info: ITreeCheckInfo<T>) => void;
    /** 默认已经加载的 keys  */
    defaultLoadedKeys?: ITreeNodeKey[];
    /** 已经加载的 Keys */
    loadedKeys?: ITreeNodeKey[];
    /** 异步加载数据 */
    loadData?: (eventData: ITreeNodeEventData<T>) => Promise<void> | void;
    /** 节点加载完毕时触发 */
    onLoad?: (loadedKeys: ITreeNodeKey[], eventData: ITreeNodeEventData<T>) => void;
    /**
     * 是否支持拖拽
     * @default false
     **/
    draggable?: boolean;
    /**
     * 判断节点是否允许 Drop
     */
    allowDrop?: ITreeAllowDrop<T>;
    /** 开始拖拽时调用 */
    onDragStart?: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    /** dragenter 触发时调用 */
    onDragEnter?: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    /** dragover 触发时调用 */
    onDragOver?: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    /** dragleave 触发时调用 */
    onDragLeave?: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    /** dragend 触发时调用 */
    onDragEnd?: (event: React.DragEvent, eventData: ITreeNodeEventData<T>) => void;
    /** drop 触发时调用 */
    onDrop?: (info: {
        event: React.DragEvent;
        node: ITreeNodeEventData<T>;
        dragNode: ITreeNodeEventData<T>;
        dragNodesKeys: ITreeNodeKey[];
        dropPosition: number;
        dropToGap: boolean;
    }) => void;
    /**
     * 根据节点数据动态设置节点 checkable、selectable、disabled、disableCheckbox，避免需要提前遍历一遍整棵树的数据来计算每个节点的值
     */
    dynamicPropsForNode?: (node: T) => Partial<Record<'checkable' | 'selectable' | 'disabled' | 'disableCheckbox', boolean>> & ICustomStyleBaseProps<ITreeNodeStyleKeys>;
}
export declare type ITreeProps<T extends ITreeNodeData = ITreeNodeData> = ITreeBaseProps<T> & Omit<React.HTMLAttributes<HTMLUListElement>, 'children' | 'onClick' | 'onDoubleClick' | 'onMouseEnter' | 'onMouseLeave' | 'onDrop' | 'onDragStart' | 'onDragEnter' | 'onDragOver' | 'onDragLeave' | 'onDragEnd' | 'onLoad' | 'onSelect'>;
/**
 * @dts[only]
 */
export declare const Tree: <T extends ITreeNodeData>(props: ITreeProps<T>) => JSX.Element;
